@@ -14,12 +14,12 @@
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -40,9 +40,19 @@ import lasso
 try:
     dataDir
 except NameError:
-    srcdir = os.environ.get('srcdir', '.')
-    dataDir = '%s/../../../tests/data' % srcdir
+    srcdir = os.environ.get('TOP_SRCDIR', '.')
+    dataDir = '%s/tests/data' % srcdir
 
+def server(local_name, remote_role, remote_name):
+    pwd = os.path.join(dataDir, local_name, 'password')
+    password = None
+    if os.path.exists(pwd):
+        password = file(pwd).read()
+    s = lasso.Server(os.path.join(dataDir, local_name, 'metadata.xml'),
+            os.path.join(dataDir, local_name, 'private-key.pem'),
+            password)
+    s.addProvider(remote_role, os.path.join(dataDir, remote_name, 'metadata.xml'))
+    return s
 
 class ServerTestCase(unittest.TestCase):
     def test01(self):
@@ -207,7 +217,60 @@ class LoginTestCase(unittest.TestCase):
         self.failUnless('<action>do</action>' in extensionsList[0])
         self.failUnless('<action2>do action 2</action2>' in extensionsList[0])
         self.failUnless('<action3>do action 3</action3>' in extensionsList[0])
-        
+
+    def test05(self):
+        '''SAMLv2 Authn request emitted and received using Artifact binding'''
+        sp = lasso.Server(
+            os.path.join(dataDir, 'sp5-saml2/metadata.xml'),
+            os.path.join(dataDir, 'sp5-saml2/private-key.pem'))
+        assert sp
+        sp.addProvider(
+            lasso.PROVIDER_ROLE_IDP,
+            os.path.join(dataDir, 'idp5-saml2/metadata.xml'))
+        sp_login = lasso.Login(sp)
+        assert sp_login
+        sp_login.initAuthnRequest(None, lasso.HTTP_METHOD_ARTIFACT_GET)
+        sp_login.buildAuthnRequestMsg()
+        sp_login_dump = sp_login.dump()
+        idp = lasso.Server(
+            os.path.join(dataDir, 'idp5-saml2/metadata.xml'),
+            os.path.join(dataDir, 'idp5-saml2/private-key.pem'))
+        idp.addProvider(
+            lasso.PROVIDER_ROLE_SP,
+            os.path.join(dataDir, 'sp5-saml2/metadata.xml'))
+        idp_login = lasso.Login(idp)
+        idp_login.initRequest(sp_login.msgUrl.split('?')[1], lasso.HTTP_METHOD_ARTIFACT_GET)
+        idp_login.buildRequestMsg()
+        sp_login2 = lasso.Login.newFromDump(sp, sp_login_dump)
+        assert isinstance(sp_login2, lasso.Login)
+        assert idp_login.msgBody
+        sp_login2.processRequestMsg(idp_login.msgBody)
+        sp_login2.buildResponseMsg()
+        assert sp_login2.msgBody
+        try:
+            idp_login.processResponseMsg(sp_login2.msgBody)
+        except:
+            raise
+        assert isinstance(idp_login.request, lasso.Samlp2AuthnRequest)
+
+    def test_06(self):
+        '''Login test between SP and IdP with encrypted private keys'''
+        sp_server = server('sp7-saml2', lasso.PROVIDER_ROLE_IDP, 'idp7-saml2')
+        idp_server = server('idp7-saml2', lasso.PROVIDER_ROLE_SP, 'sp7-saml2')
+
+        sp_login = lasso.Login(sp_server)
+        sp_login.initAuthnRequest()
+        sp_login.request.protocolBinding = lasso.SAML2_METADATA_BINDING_POST;
+        sp_login.buildAuthnRequestMsg()
+        idp_login = lasso.Login(idp_server)
+        idp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        idp_login.processAuthnRequestMsg(sp_login.msgUrl.split('?')[1])
+        idp_login.validateRequestMsg(True, True)
+        idp_login.buildAssertion("None", "None", "None", "None", "None")
+        idp_login.buildAuthnResponseMsg()
+        sp_login.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE)
+        sp_login.processAuthnResponseMsg(idp_login.msgBody)
+        sp_login.acceptSso()
 
 class LogoutTestCase(unittest.TestCase):
     def test01(self):
@@ -294,21 +357,6 @@ class LogoutTestCase(unittest.TestCase):
         else:
             self.fail('Logout processResponseMsg should have failed.')
 
-    def test05(self):
-        """IDP logout; testing logout dump & newFromDump()."""
-
-        lassoServer = lasso.Server(
-            os.path.join(dataDir, 'idp1-la/metadata.xml'),
-            os.path.join(dataDir, 'idp1-la/private-key-raw.pem'),
-            None,
-            os.path.join(dataDir, 'idp1-la/certificate.pem'))
-        lassoServer.addProvider(
-            lasso.PROVIDER_ROLE_SP,
-            os.path.join(dataDir, 'sp1-la/metadata.xml'),
-            os.path.join(dataDir, 'sp1-la/public-key.pem'),
-            os.path.join(dataDir, 'sp1-la/certificate.pem'))
-
-
 class DefederationTestCase(unittest.TestCase):
     def test01(self):
         """IDP initiated defederation; testing processNotificationMsg with non Liberty query."""
@@ -344,15 +392,88 @@ class IdentityTestCase(unittest.TestCase):
         newIdentityDump = identity.dump()
         self.failUnlessEqual(identityDump, newIdentityDump)
 
+class AttributeAuthorityTestCase(unittest.TestCase):
+    def test01(self):
+        '''Attribute request and response test between sp5 and idp6'''
+        s = lasso.Server(
+                os.path.join(dataDir, 'sp5-saml2/metadata.xml'),
+                os.path.join(dataDir, 'sp5-saml2/private-key.pem'))
+        s.addProvider(lasso.PROVIDER_ROLE_ATTRIBUTE_AUTHORITY,
+                os.path.join(dataDir, 'idp6-saml2/metadata.xml'))
+
+        s2 = lasso.Server(
+                os.path.join(dataDir, 'idp6-saml2/metadata.xml'),
+                os.path.join(dataDir, 'idp6-saml2/private-key.pem'))
+        s2.addProvider(lasso.PROVIDER_ROLE_SP,
+                os.path.join(dataDir, 'sp5-saml2/metadata.xml'))
+
+        aq = lasso.AssertionQuery(s)
+        rpid = s.providers.keys()[0]
+        aq.initRequest(rpid,
+                lasso.HTTP_METHOD_SOAP,
+                lasso.ASSERTION_QUERY_REQUEST_TYPE_ATTRIBUTE)
+        assert aq.request
+        assert aq.remoteProviderId == rpid
+        nid = lasso.Saml2NameID.newWithPersistentFormat(
+                lasso.buildUniqueId(32),
+                s.providerId, s2.providerId)
+        aq.nameIdentifier = nid
+        aq.addAttributeRequest(
+                lasso.SAML2_ATTRIBUTE_NAME_FORMAT_BASIC,
+                'testAttribute')
+        aq.buildRequestMsg()
+        assert aq.msgUrl
+        assert aq.msgBody
+
+        aq2 = lasso.AssertionQuery(s2)
+        aq2.processRequestMsg(aq.msgBody)
+        assert aq.request
+        aq2.validateRequest()
+        assert aq2.response
+        assertion = lasso.Saml2Assertion()
+        aq2.response.assertion = (assertion, )
+        for attribute in aq2.request.attribute:
+            content = lasso.MiscTextNode.newWithString("xxx")
+            content.textChild = True
+            assertion.addAttributeWithNode(attribute.name, attribute.nameFormat,
+                    content)
+            assertion.addAttributeWithNode(attribute.name, attribute.nameFormat,
+                    content)
+        assertion.subject = aq.request.subject
+        s2.saml2AssertionSetupSignature(assertion)
+        aq2.buildResponseMsg()
+        aq.processResponseMsg(aq2.msgBody)
+        assert aq.response
+        assert aq.response.assertion[0]
+        assert aq.response.assertion[0].attributeStatement[0]
+        assert aq.response.assertion[0].attributeStatement[0].attribute[0]
+        assert aq.response.assertion[0].attributeStatement[0].attribute[0].attributeValue[0]
+
+class LogoutTestCase(unittest.TestCase):
+    def test01(self):
+        '''Test parsing of a logout request with more than one session index'''
+        content = '''<samlp:LogoutRequest xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol" ID="xxxx" Version="2.0" IssueInstant="2010-06-14T22:00:00">
+        <samlp:Issuer>me</samlp:Issuer>
+        <samlp:SessionIndex>id1</samlp:SessionIndex>
+        <samlp:SessionIndex>id2</samlp:SessionIndex>
+        <samlp:SessionIndex>id3</samlp:SessionIndex>
+        </samlp:LogoutRequest>'''
+
+        node = lasso.Samlp2LogoutRequest.newFromXmlNode(content)
+        assert isinstance(node, lasso.Samlp2LogoutRequest)
+        assert node.sessionIndex == 'id3'
+        assert node.sessionIndexes == ('id1', 'id2', 'id3')
 
 serverSuite = unittest.makeSuite(ServerTestCase, 'test')
 loginSuite = unittest.makeSuite(LoginTestCase, 'test')
 logoutSuite = unittest.makeSuite(LogoutTestCase, 'test')
 defederationSuite = unittest.makeSuite(DefederationTestCase, 'test')
 identitySuite = unittest.makeSuite(IdentityTestCase, 'test')
+attributeSuite = unittest.makeSuite(AttributeAuthorityTestCase, 'test')
+logoutSuite = unittest.makeSuite(LogoutTestCase, 'test')
 
 allTests = unittest.TestSuite((serverSuite, loginSuite, logoutSuite, defederationSuite,
-                               identitySuite))
+                               identitySuite, attributeSuite, logoutSuite))
 
 if __name__ == '__main__':
     sys.exit(not unittest.TextTestRunner(verbosity = 2).run(allTests).wasSuccessful())
