@@ -1,22 +1,22 @@
-/* $Id: lecp.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -28,11 +28,15 @@
  *
  **/
 
+#include "../xml/private.h"
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
-#include <lasso/id-ff/lecp.h>
-#include <lasso/id-ff/profileprivate.h>
+#include "lecp.h"
+#include "profileprivate.h"
+#include "../utils.h"
+
+#include "../utils.h"
 
 /*****************************************************************************/
 /* public methods                                                            */
@@ -71,10 +75,10 @@ lasso_lecp_build_authn_request_envelope_msg(LassoLecp *lecp)
 		return LASSO_PROFILE_ERROR_MISSING_REQUEST;
 	}
 
-	lecp->authnRequestEnvelope = lasso_lib_authn_request_envelope_new_full(
+	lasso_assign_new_gobject(lecp->authnRequestEnvelope, lasso_lib_authn_request_envelope_new_full(
 			LASSO_LIB_AUTHN_REQUEST(profile->request),
 			LASSO_PROVIDER(profile->server)->ProviderID,
-			assertionConsumerServiceURL);
+			assertionConsumerServiceURL));
 	if (lecp->authnRequestEnvelope == NULL) {
 		return critical_error(LASSO_PROFILE_ERROR_BUILDING_REQUEST_FAILED);
 	}
@@ -84,14 +88,14 @@ lasso_lecp_build_authn_request_envelope_msg(LassoLecp *lecp)
 	LASSO_SAMLP_REQUEST_ABSTRACT(lecp->authnRequestEnvelope->AuthnRequest)->certificate_file =
 		LASSO_PROFILE(lecp)->server->certificate;
 	msg = lasso_node_get_xmlNode(LASSO_NODE(lecp->authnRequestEnvelope), FALSE);
-	
+
 	/* msg is not SOAP but straight XML */
 	handler = xmlFindCharEncodingHandler("utf-8");
-	buf = xmlAllocOutputBuffer(handler); 
+	buf = xmlAllocOutputBuffer(handler);
 	xmlNodeDumpOutput(buf, NULL, msg, 0, 0, "utf-8");
 	xmlOutputBufferFlush(buf);
 
-	profile->msg_body = g_strdup(
+	lasso_assign_string(profile->msg_body,
 			(char*)(buf->conv ? buf->conv->content : buf->buffer->content));
 	xmlOutputBufferClose(buf);
 	xmlFreeNode(msg);
@@ -106,10 +110,10 @@ lasso_lecp_build_authn_request_envelope_msg(LassoLecp *lecp)
 /**
  * lasso_lecp_build_authn_request_msg:
  * @lecp: a #LassoLecp
- * 
+ *
  * Builds an authentication request. The data for the sending of the request are
  * stored in @msg_url and @msg_body (SOAP POST).
- * 
+ *
  * Return value: 0 on success; or a negative value otherwise.
  **/
 int
@@ -123,15 +127,16 @@ lasso_lecp_build_authn_request_msg(LassoLecp *lecp)
 	profile = LASSO_PROFILE(lecp);
 
 	if (profile->remote_providerID == NULL) {
-		/* this means lasso_logout_init_request was not called before */
 		return critical_error(LASSO_PROFILE_ERROR_MISSING_REMOTE_PROVIDERID);
 	}
 
-	remote_provider = g_hash_table_lookup(profile->server->providers,
-			profile->remote_providerID);
+	remote_provider = lasso_server_get_provider(profile->server, profile->remote_providerID);
+	if (remote_provider == NULL) {
+		return critical_error(LASSO_SERVER_ERROR_PROVIDER_NOT_FOUND);
+	}
 
-	profile->msg_url  = lasso_provider_get_metadata_one(
-			remote_provider, "SingleSignOnServiceURL");
+	lasso_assign_new_string(profile->msg_url, lasso_provider_get_metadata_one(
+			remote_provider, "SingleSignOnServiceURL"));
 	/* msg_body has usally been set in
 	 * lasso_lecp_process_authn_request_envelope_msg() */
 	if (profile->msg_body == NULL)
@@ -160,11 +165,11 @@ lasso_lecp_build_authn_response_msg(LassoLecp *lecp)
 	profile = LASSO_PROFILE(lecp);
 	lasso_profile_clean_msg_info(profile);
 
-	profile->msg_url = g_strdup(lecp->assertionConsumerServiceURL);
+	lasso_assign_string(profile->msg_url, lecp->assertionConsumerServiceURL);
 	if (profile->msg_url == NULL) {
 		return critical_error(LASSO_PROFILE_ERROR_UNKNOWN_PROFILE_URL);
 	}
-	profile->msg_body = lasso_node_export_to_base64(LASSO_NODE(profile->response));
+	lasso_assign_new_string(profile->msg_body, lasso_node_export_to_base64(LASSO_NODE(profile->response)));
 	if (profile->msg_body == NULL) {
 		return critical_error(LASSO_PROFILE_ERROR_BUILDING_MESSAGE_FAILED);
 	}
@@ -197,7 +202,7 @@ lasso_lecp_build_authn_response_envelope_msg(LassoLecp *lecp)
 		return LASSO_PROFILE_ERROR_MISSING_RESPONSE;
 	}
 
-	provider = g_hash_table_lookup(profile->server->providers, profile->remote_providerID);
+	provider = lasso_server_get_provider(profile->server, profile->remote_providerID);
 	if (provider == NULL) {
 		return critical_error(LASSO_SERVER_ERROR_PROVIDER_NOT_FOUND);
 	}
@@ -211,16 +216,12 @@ lasso_lecp_build_authn_response_envelope_msg(LassoLecp *lecp)
 		return critical_error(LASSO_PROFILE_ERROR_UNKNOWN_PROFILE_URL);
 	}
 
-	if (LASSO_PROFILE(lecp)->msg_body)
-		g_free(LASSO_PROFILE(lecp)->msg_body);
+	lasso_release (LASSO_PROFILE(lecp)->msg_body);
+	lasso_release (LASSO_PROFILE(lecp)->msg_url);
 
-	if (LASSO_PROFILE(lecp)->msg_url)
-		g_free(LASSO_PROFILE(lecp)->msg_url);
-	LASSO_PROFILE(lecp)->msg_url = NULL;
-
-	lecp->authnResponseEnvelope = lasso_lib_authn_response_envelope_new(
+	lasso_assign_new_gobject(lecp->authnResponseEnvelope, lasso_lib_authn_response_envelope_new(
 			LASSO_LIB_AUTHN_RESPONSE(profile->response),
-			assertionConsumerServiceURL);
+			assertionConsumerServiceURL));
 	LASSO_SAMLP_RESPONSE_ABSTRACT(lecp->authnResponseEnvelope->AuthnResponse
 			)->private_key_file = profile->server->private_key;
 	LASSO_SAMLP_RESPONSE_ABSTRACT(lecp->authnResponseEnvelope->AuthnResponse
@@ -268,7 +269,7 @@ lasso_lecp_init_authn_request(LassoLecp *lecp, const char *remote_providerID)
  *
  * Processes received authentication request, checks it is signed correctly,
  * checks if requested protocol profile is supported, etc.
- * 
+ *
  * Return value: 0 on success; or a negative value otherwise.
  **/
 int
@@ -288,7 +289,7 @@ lasso_lecp_process_authn_request_msg(LassoLecp *lecp, const char *authn_request_
  *
  * Processes received enveloped authentication request, extracts the
  * authentication request out of it.
- * 
+ *
  * Return value: 0 on success; or a negative value otherwise.
  **/
 int
@@ -324,7 +325,7 @@ lasso_lecp_process_authn_request_envelope_msg(LassoLecp *lecp, const char *reque
 	authn_request = xmlCopyNode(xpathObj->nodesetval->nodeTab[0], 1);
 	xmlXPathFreeContext(xpathCtx);
 	xmlXPathFreeObject(xpathObj);
-	xmlFreeDoc(doc);
+	lasso_release_doc(doc);
 	xpathCtx = NULL;
 	xpathObj = NULL;
 	doc = NULL;
@@ -357,7 +358,7 @@ lasso_lecp_process_authn_request_envelope_msg(LassoLecp *lecp, const char *reque
  *
  * Processes received enveloped authentication response, extracts the
  * authentication response out of it and stores it in @response.
- * 
+ *
  * Return value: 0 on success; or a negative value otherwise.
  **/
 int
@@ -397,7 +398,7 @@ lasso_lecp_process_authn_response_envelope_msg(LassoLecp *lecp, const char *resp
  * @lecp: a #LassoLecp
  *
  * Destroys a #LassoLecp object
- * 
+ *
  **/
 void
 lasso_lecp_destroy(LassoLecp *lecp)
@@ -417,7 +418,7 @@ static LassoNodeClass *parent_class = NULL;
 
 static void
 finalize(GObject *object)
-{  
+{
 	G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
@@ -437,7 +438,7 @@ static void
 class_init(LassoLecpClass *klass)
 {
 	parent_class = g_type_class_peek_parent(klass);
-	
+
 	G_OBJECT_CLASS(klass)->finalize = finalize;
 }
 
@@ -457,6 +458,7 @@ lasso_lecp_get_type()
 			sizeof(LassoLecp),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_LOGIN,
