@@ -1,22 +1,22 @@
-/* $Id: profile.c 3793 2008-07-22 12:09:06Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -28,24 +28,69 @@
  *
  **/
 
+#include "../xml/private.h"
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
-#include <lasso/xml/samlp_response.h>
-#include <lasso/xml/samlp_request.h>
-#include <lasso/xml/lib_authn_response.h>
-#include <lasso/xml/lib_status_response.h>
+#include "../xml/samlp_response.h"
+#include "../xml/samlp_request.h"
+#include "../xml/lib_authn_response.h"
+#include "../xml/lib_status_response.h"
 
-#include <lasso/id-ff/profile.h>
-#include <lasso/id-ff/profileprivate.h>
-#include <lasso/id-ff/providerprivate.h>
+#include "profile.h"
+#include "profileprivate.h"
+#include "providerprivate.h"
+#include "./sessionprivate.h"
 
-#include <lasso/saml-2.0/profileprivate.h>
+#include "../saml-2.0/profileprivate.h"
+#include "../xml/saml-2.0/saml2_name_id.h"
+#include "../xml/saml_name_identifier.h"
+#include "../xml/saml-2.0/saml2_assertion.h"
+#include "../xml/soap-1.1/soap_fault.h"
+#include "../utils.h"
+#include "../debug.h"
+#ifdef LASSO_WSF_ENABLED
+#include "../xml/idwsf_strings.h"
+#include "../xml/id-wsf-2.0/idwsf2_strings.h"
+#endif
+#include "../lasso_config.h"
 
 /*****************************************************************************/
 /* public functions                                                          */
 /*****************************************************************************/
 
+static LassoNode*
+_lasso_saml_assertion_get_name_id(LassoSamlAssertion *assertion) 
+{
+	LassoSamlAuthenticationStatement *authn_statement;
+	LassoSamlSubject *subject;
+
+	goto_cleanup_if_fail(LASSO_IS_SAML_ASSERTION(assertion));
+	authn_statement = assertion->AuthenticationStatement;
+	goto_cleanup_if_fail(LASSO_IS_SAML_AUTHENTICATION_STATEMENT(authn_statement));
+	subject = authn_statement->parent.Subject;
+	goto_cleanup_if_fail(LASSO_IS_SAML_SUBJECT(subject));
+	if (LASSO_IS_SAML_NAME_IDENTIFIER(subject->NameIdentifier))
+		return (LassoNode*)subject->NameIdentifier;
+cleanup:
+	return NULL;
+}
+
+static LassoNode*
+_lasso_saml2_assertion_get_name_id(LassoSaml2Assertion *assertion)
+{
+	LassoSaml2Subject *subject;
+
+	goto_cleanup_if_fail(LASSO_SAML2_ASSERTION(assertion));
+	subject = assertion->Subject;
+	goto_cleanup_if_fail(LASSO_SAML2_SUBJECT(subject));
+	if (LASSO_IS_SAML2_NAME_ID(subject->NameID))
+		return (LassoNode*)subject->NameID;
+
+cleanup:
+	return NULL;
+}
+
 /**
  * lasso_profile_get_nameIdentifier:
  * @profile: a #LassoProfile
@@ -54,7 +99,7 @@
  * identifier (which is actually a #LassoSamlNameIdentifier in ID-FF 1.2 and
  * #LassoSaml2NameID in SAML 2.0).
  *
- * Return value: the name identifier or NULL if none was found.  The #LassoNode
+ * Return value:(transfer none): the name identifier or NULL if none was found.  The #LassoNode
  *     object is internally allocated and must not be freed by the caller.
  **/
 LassoNode*
@@ -62,35 +107,51 @@ lasso_profile_get_nameIdentifier(LassoProfile *profile)
 {
 	LassoProvider *remote_provider;
 	LassoFederation *federation;
-	char *name_id_sp_name_qualifier;
+	const char *name_id_sp_name_qualifier;
 
-	g_return_val_if_fail(LASSO_IS_PROFILE(profile), NULL);
-
-	g_return_val_if_fail(LASSO_IS_SERVER(profile->server), NULL);
-	g_return_val_if_fail(LASSO_IS_IDENTITY(profile->identity), NULL);
-	g_return_val_if_fail(profile->remote_providerID != NULL, NULL);
-
-	remote_provider = g_hash_table_lookup(
-			profile->server->providers, profile->remote_providerID);
-	if (remote_provider == NULL)
+	if (!LASSO_IS_PROFILE(profile)) {
 		return NULL;
-
-	if (remote_provider->private_data->affiliation_id) {
-		name_id_sp_name_qualifier = remote_provider->private_data->affiliation_id;
-	} else {
-		name_id_sp_name_qualifier = profile->remote_providerID;
 	}
 
-	federation = g_hash_table_lookup(
-			profile->identity->federations,
-			name_id_sp_name_qualifier);
-	if (federation == NULL)
+	if (profile->remote_providerID == NULL)
 		return NULL;
 
-	if (federation->remote_nameIdentifier)
-		return federation->remote_nameIdentifier;
+	/* For transient federations, we must look at assertions no federation object exists */
+	if (LASSO_IS_SESSION(profile->session)) {
+		LassoNode *assertion, *name_id;
 
-	return federation->local_nameIdentifier;
+		assertion = lasso_session_get_assertion(profile->session,
+				profile->remote_providerID);
+
+		name_id = _lasso_saml_assertion_get_name_id((LassoSamlAssertion*)assertion);
+		if (name_id)
+			return name_id;
+		name_id = _lasso_saml2_assertion_get_name_id((LassoSaml2Assertion*)assertion);
+		if (name_id)
+			return name_id;
+	}
+	/* beware, it is not a real loop ! */
+	if (LASSO_IS_IDENTITY(profile->identity)) do {
+		remote_provider = lasso_server_get_provider(profile->server, profile->remote_providerID);
+		if (remote_provider == NULL)
+			break;
+
+		name_id_sp_name_qualifier = lasso_provider_get_sp_name_qualifier(remote_provider);
+		if (name_id_sp_name_qualifier == NULL)
+			break;
+
+		federation = g_hash_table_lookup(
+				profile->identity->federations,
+				name_id_sp_name_qualifier);
+		if (federation == NULL)
+			break;
+
+		if (federation->remote_nameIdentifier)
+			return federation->remote_nameIdentifier;
+		return federation->local_nameIdentifier;
+	} while (FALSE);
+
+	return NULL;
 }
 
 /**
@@ -110,11 +171,18 @@ lasso_profile_get_request_type_from_soap_msg(const gchar *soap)
 	LassoRequestType type = LASSO_REQUEST_TYPE_INVALID;
 	const char *name = NULL;
 	xmlNs *ns = NULL;
+	xmlError error;
 
+	memset(&error, 0, sizeof(xmlError));
 	if (soap == NULL)
 		return LASSO_REQUEST_TYPE_INVALID;
 
-	doc = xmlParseMemory(soap, strlen(soap));
+	doc = lasso_xml_parse_memory_with_error(soap, strlen(soap), &error);
+	if (! doc) {
+		message(G_LOG_LEVEL_WARNING, "Invalid soap message: %s", error.message);
+		type = LASSO_REQUEST_TYPE_INVALID;
+		goto cleanup;
+	}
 	xpathCtx = xmlXPathNewContext(doc);
 	xmlXPathRegisterNs(xpathCtx, (xmlChar*)"s", (xmlChar*)LASSO_SOAP_ENV_HREF);
 	xpathObj = xmlXPathEvalExpression((xmlChar*)"//s:Body/*", xpathCtx);
@@ -138,10 +206,13 @@ lasso_profile_get_request_type_from_soap_msg(const gchar *soap)
 		type = LASSO_REQUEST_TYPE_NAME_IDENTIFIER_MAPPING;
 	} else if (strcmp(name, "AuthnRequest") == 0) {
 		type = LASSO_REQUEST_TYPE_LECP;
+	} else if (strcmp(name, "ManageNameIDRequest") == 0) {
+		type = LASSO_REQUEST_TYPE_NAME_ID_MANAGEMENT;
+#ifdef LASSO_WSF_ENABLED
 	} else if (strcmp(name, "Query") == 0) {
 		if (strcmp((char*)ns->href, LASSO_DISCO_HREF) == 0) {
 			type = LASSO_REQUEST_TYPE_DISCO_QUERY;
-		} else if (strcmp((char*)ns->href, LASSO_IDWSF2_DISCO_HREF) == 0) {
+		} else if (strcmp((char*)ns->href, LASSO_IDWSF2_DISCOVERY_HREF) == 0) {
 			type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_QUERY;
 		} else {
 			type = LASSO_REQUEST_TYPE_DST_QUERY;
@@ -150,24 +221,24 @@ lasso_profile_get_request_type_from_soap_msg(const gchar *soap)
 		if (strcmp((char*)ns->href, LASSO_DISCO_HREF) == 0) {
 			type = LASSO_REQUEST_TYPE_DISCO_MODIFY;
 		} else {
-			type = LASSO_REQUEST_TYPE_DST_MODIFY;	
+			type = LASSO_REQUEST_TYPE_DST_MODIFY;
 		}
 	} else if (strcmp(name, "SASLRequest") == 0) {
 		type = LASSO_REQUEST_TYPE_SASL_REQUEST;
-	} else if (strcmp(name, "ManageNameIDRequest") == 0) {
-		type = LASSO_REQUEST_TYPE_NAME_ID_MANAGEMENT;
 	} else if (strcmp(name, "SvcMDRegister") == 0) {
 		type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_REGISTER;
 	} else if (strcmp(name, "SvcMDAssociationAdd") == 0) {
 		type = LASSO_REQUEST_TYPE_IDWSF2_DISCO_SVCMD_ASSOCIATION_ADD;
+#endif
 	} else {
 		message(G_LOG_LEVEL_WARNING, "Unknown node name : %s", name);
 	}
 
 	xmlXPathFreeObject(xpathObj);
 	xmlXPathFreeContext(xpathCtx);
-	xmlFreeDoc(doc);
-
+cleanup:
+	lasso_release_doc(doc);
+	xmlResetError(&error);
 	return type;
 }
 
@@ -214,7 +285,7 @@ lasso_profile_is_liberty_query(const gchar *query)
  *
  * Gets the identity bound to @profile.
  *
- * Return value: the identity or NULL if it none was found.  The #LassoIdentity
+ * Return value:(transfer none): the identity or NULL if it none was found.  The #LassoIdentity
  *      object is internally allocated and must not be freed by the caller.
  **/
 LassoIdentity*
@@ -232,7 +303,7 @@ lasso_profile_get_identity(LassoProfile *profile)
  *
  * Gets the session bound to @profile.
  *
- * Return value: the session or NULL if it none was found.  The #LassoSession
+ * Return value:(transfer none): the session or NULL if it none was found.  The #LassoSession
  *      object is internally allocated and must not be freed by the caller.
  **/
 LassoSession*
@@ -274,7 +345,7 @@ lasso_profile_is_identity_dirty(LassoProfile *profile)
 gboolean
 lasso_profile_is_session_dirty(LassoProfile *profile)
 {
-	return (profile->session && profile->session->is_dirty);
+	return LASSO_IS_SESSION(profile->session) && lasso_session_is_dirty(profile->session);
 }
 
 
@@ -309,35 +380,26 @@ lasso_profile_set_response_status(LassoProfile *profile, const char *statusCodeV
 
 	if (LASSO_IS_SAMLP_RESPONSE(profile->response)) {
 		LassoSamlpResponse *response = LASSO_SAMLP_RESPONSE(profile->response);
-		if (response->Status) lasso_node_destroy(LASSO_NODE(response->Status));
-		response->Status = status;
+		lasso_assign_new_gobject(response->Status, status);
 		return;
 	}
 	if (LASSO_IS_LIB_STATUS_RESPONSE(profile->response)) {
 		LassoLibStatusResponse *response = LASSO_LIB_STATUS_RESPONSE(profile->response);
-		if (response->Status) lasso_node_destroy(LASSO_NODE(response->Status));
-		response->Status = status;
+		lasso_assign_new_gobject(response->Status, status);
 		return;
 	}
 
 	message(G_LOG_LEVEL_CRITICAL, "Failed to set status");
 	g_assert_not_reached();
-} 
+}
 
 void
 lasso_profile_clean_msg_info(LassoProfile *profile)
 {
-	if (profile->msg_url) {
-		g_free(profile->msg_url);
-		profile->msg_url = NULL;
-	}
-	if (profile->msg_body) {
-		g_free(profile->msg_body);
-		profile->msg_body = NULL;
-	}
+	lasso_release_string(profile->msg_url);
+	lasso_release_string(profile->msg_body);
 }
 
-
 /**
  * lasso_profile_set_identity_from_dump:
  * @profile: a #LassoProfile
@@ -352,12 +414,10 @@ lasso_profile_set_identity_from_dump(LassoProfile *profile, const gchar *dump)
 {
 	g_return_val_if_fail(dump != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
-	if (profile->identity) {
-		g_object_unref(profile->identity);
-	}
-	profile->identity = lasso_identity_new_from_dump(dump);
-	if (profile->identity == NULL)
+	lasso_assign_new_gobject(profile->identity, lasso_identity_new_from_dump(dump));
+	if (profile->identity == NULL) {
 		return critical_error(LASSO_PROFILE_ERROR_BAD_IDENTITY_DUMP);
+	}
 
 	return 0;
 }
@@ -377,41 +437,88 @@ lasso_profile_set_session_from_dump(LassoProfile *profile, const gchar *dump)
 {
 	g_return_val_if_fail(dump != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
-	if (profile->session) {
-		g_object_unref(profile->session);
-	}
-	profile->session = lasso_session_new_from_dump(dump);
+	lasso_assign_new_gobject(profile->session, lasso_session_new_from_dump(dump));
 	if (profile->session == NULL)
 		return critical_error(LASSO_PROFILE_ERROR_BAD_SESSION_DUMP);
-	
+
 	IF_SAML2(profile) {
 		lasso_saml20_profile_set_session_from_dump(profile);
 	}
 
-	profile->session->is_dirty = FALSE;
-
 	return 0;
 }
 
+/**
+ * lasso_profile_get_artifact:
+ * @profile: a #LassoProfile object
+ *
+ * Return the artifact token
+ *
+ * Return value:(transfer full)(allow-none): a newly allocated string or NULL.
+ */
 char*
 lasso_profile_get_artifact(LassoProfile *profile)
 {
 	return g_strdup(profile->private_data->artifact);
 }
 
+/**
+ * lasso_profile_get_artifact_message:
+ * @profile: a #LassoProfile object
+ *
+ * Return the artifact message.
+ *
+ * Return value:(transfer full)(allow-none): a newly allocated string or NULL
+ */
 char*
 lasso_profile_get_artifact_message(LassoProfile *profile)
 {
 	return g_strdup(profile->private_data->artifact_message);
 }
 
+/**
+ * lasso_profile_set_artifact_message:
+ * @profile: a #LassoProfile object
+ * @message: the artifact message content
+ *
+ * Set @message as the content for the ArtifactResolve response.
+ *
+ */
 void
-lasso_profile_set_artifact_message(LassoProfile *profile, char *message)
+lasso_profile_set_artifact_message(LassoProfile *profile, const char *message)
 {
-	if (profile->private_data->artifact_message) {
-		g_free(profile->private_data->artifact_message);
+	if (! LASSO_IS_PROFILE(profile)) {
+		message(G_LOG_LEVEL_CRITICAL, "set_artifact_message called on something not a" \
+			"LassoProfile object: %p", profile);
+		return;
 	}
-	profile->private_data->artifact_message = g_strdup(message);
+	lasso_assign_string(profile->private_data->artifact_message, message);
+}
+
+/**
+ * lasso_profile_get_server:
+ * @profile: a #LassoProfile object
+ *
+ * Return the #LassoServer linked to this profile object. A profile object should always contains
+ * one. It allows to find metadatas of other providers and to know our own metadatas.
+ *
+ * Return value: (transfer none): a #LassoServer or NULL if profile is not a #LassoProfile or no
+ * #LassoServer object was setup at the creation of this profile.
+ */
+LassoServer*
+lasso_profile_get_server(LassoProfile *profile)
+{
+	g_return_val_if_fail(LASSO_IS_PROFILE(profile), NULL);
+
+	if (profile->server) {
+		if (LASSO_IS_SERVER(profile->server)) {
+			return profile->server;
+		} else {
+			message(G_LOG_LEVEL_WARNING, "profile->server contains a non LassoServer object");
+		}
+	}
+
+	return NULL;
 }
 
 
@@ -420,17 +527,19 @@ lasso_profile_set_artifact_message(LassoProfile *profile, char *message)
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "Request", SNIPPET_NODE_IN_CHILD, G_STRUCT_OFFSET(LassoProfile, request) },
-	{ "Response", SNIPPET_NODE_IN_CHILD, G_STRUCT_OFFSET(LassoProfile, response) },
+	{ "Request", SNIPPET_NODE_IN_CHILD, G_STRUCT_OFFSET(LassoProfile, request), NULL, NULL, NULL},
+	{ "Response", SNIPPET_NODE_IN_CHILD, G_STRUCT_OFFSET(LassoProfile, response), NULL, NULL, NULL},
 	{ "NameIdentifier", SNIPPET_NODE_IN_CHILD,
-		G_STRUCT_OFFSET(LassoProfile, nameIdentifier) },
-	{ "RemoteProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, remote_providerID) },
-	{ "MsgUrl", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_url) },
-	{ "MsgBody", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_body) },
-	{ "MsgRelayState", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_relayState) },
+		G_STRUCT_OFFSET(LassoProfile, nameIdentifier), NULL, NULL, NULL},
+	{ "RemoteProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, remote_providerID),
+		NULL, NULL, NULL},
+	{ "MsgUrl", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_url), NULL, NULL, NULL},
+	{ "MsgBody", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_body), NULL, NULL, NULL},
+	{ "MsgRelayState", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoProfile, msg_relayState), NULL,
+		NULL, NULL},
 	{ "HttpRequestMethod", SNIPPET_CONTENT | SNIPPET_INTEGER,
-		G_STRUCT_OFFSET(LassoProfile, http_request_method) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoProfile, http_request_method), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -464,7 +573,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 	xmlNode *t;
 
 	parent_class->init_from_xml(node, xmlnode);
-	
+
 	if (xmlnode == NULL)
 		return LASSO_XML_ERROR_OBJECT_CONSTRUCTION_FAILED;
 
@@ -479,11 +588,11 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 		if (strcmp((char*)t->name, "Artifact") == 0) {
 			s = xmlNodeGetContent(t);
-			profile->private_data->artifact = g_strdup((char*)s);
+			lasso_assign_string(profile->private_data->artifact, (char*)s);
 			xmlFree(s);
 		} else if (strcmp((char*)t->name, "ArtifactMessage") == 0) {
 			s = xmlNodeGetContent(t);
-			profile->private_data->artifact_message = g_strdup((char*)s);
+			lasso_assign_string(profile->private_data->artifact_message, (char*)s);
 			xmlFree(s);
 		}
 
@@ -493,7 +602,192 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 	return 0;
 }
 
+/**
+ * lasso_profile_set_signature_hint:
+ * @profile: a #LassoProfile object
+ * @signature_hint: wheter next produced messages should be signed or not (or let Lasso choose from
+ * implicit information).
+ *
+ * By default each profile will choose to sign or not its messages, this method allow to force or
+ * forbid the signature of messages, on a per transaction basis.
+ */
+void
+lasso_profile_set_signature_hint(LassoProfile *profile, LassoProfileSignatureHint signature_hint)
+{
+	if (! LASSO_IS_PROFILE(profile) && ! profile->private_data)
+		return;
+	profile->private_data->signature_hint = signature_hint;
+}
 
+/**
+ * lasso_profile_get_signature_hint:
+ * @profile: a #LassoProfile object
+ *
+ * Return the value of the signature hint attribute (see lasso_profile_set_signature_hint()).
+ *
+ * Return value: a value in the enum type #LassoProfileSignatureHint.
+ */
+LassoProfileSignatureHint
+lasso_profile_get_signature_hint(LassoProfile *profile)
+{
+	LassoProfileSignatureVerifyHint signature_verify_hint;
+	if (! LASSO_IS_PROFILE(profile) && ! profile->private_data)
+		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
+	signature_verify_hint = profile->private_data->signature_verify_hint;
+	if (signature_verify_hint >= LASSO_PROFILE_SIGNATURE_VERIFY_HINT_LAST) {
+		message(G_LOG_LEVEL_WARNING, "%u is an invalid signature verify hint",
+				signature_verify_hint);
+		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
+	}
+	return profile->private_data->signature_hint;
+}
+
+/**
+ * lasso_profile_set_signature_verify_hint:
+ * @profile: a #LassoProfile object
+ * @signature_verify_hint: whether next received message signatures should be checked or not (or let
+ * Lasso choose from implicit information).
+ *
+ * By default each profile will choose to verify or not its messages, this method allow to force or
+ * forbid the signature of messages, on a per transaction basis.
+ */
+void
+lasso_profile_set_signature_verify_hint(LassoProfile *profile,
+		LassoProfileSignatureVerifyHint signature_verify_hint)
+{
+	if (! LASSO_IS_PROFILE(profile) && ! profile->private_data)
+		return;
+	if (signature_verify_hint >= LASSO_PROFILE_SIGNATURE_VERIFY_HINT_LAST) {
+		message(G_LOG_LEVEL_WARNING, "%i is an invalid argument for " __FUNCTION__,
+				signature_verify_hint);
+		return;
+	}
+	profile->private_data->signature_verify_hint = signature_verify_hint;
+}
+
+/**
+ * lasso_profile_get_signature_verify_hint:
+ * @profile: a #LassoProfile object
+ *
+ * Return the value of the signature verify hint attribute (see
+ * lasso_profile_set_signature_verify_hint()).
+ *
+ * Return value: a value in the enum type #LassoProfileSignatureVerifyHint.
+ */
+LassoProfileSignatureVerifyHint
+lasso_profile_get_signature_verify_hint(LassoProfile *profile)
+{
+	if (! LASSO_IS_PROFILE(profile) && ! profile->private_data)
+		return LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
+	return profile->private_data->signature_verify_hint;
+}
+
+
+/**
+ * lasso_profile_set_soap_fault_response:
+ * @profile: a #LassoProfile object
+ * @faultcode: the code for the SOAP fault
+ * @faultstring:(allow-none): the description for the SOAP fault
+ * @details:(element-type LassoNode)(allow-none): a list of nodes to add as details
+ *
+ * Set the response to a SOAP fault, using @faultcode, @faultstring, and @details to initialize it.
+ *
+ * Return value: 0 if successful, an error code otherwise.
+ */
+gint
+lasso_profile_set_soap_fault_response(LassoProfile *profile, const char *faultcode,
+		const char *faultstring, GList *details)
+{
+	LassoSoapFault *fault;
+
+	if (! LASSO_IS_SOAP_FAULT(profile->response)) {
+		lasso_release_gobject(profile->response);
+		profile->response = (LassoNode*)lasso_soap_fault_new();
+	}
+	fault = (LassoSoapFault*)profile->response;
+	lasso_assign_string(fault->faultcode, faultcode);
+	lasso_assign_string(fault->faultstring, faultstring);
+	if (details) {
+		if (! fault->Detail) {
+			fault->Detail = lasso_soap_detail_new();
+		}
+		lasso_assign_list_of_gobjects(fault->Detail->any, details);
+	} else {
+		lasso_release_gobject(fault->Detail);
+	}
+	return 0;
+}
+
+/**
+ * lasso_profile_sso_role_with:
+ * @profile: a #LassoProfile object
+ * @remote_provider_id: the identifier of a provider
+ *
+ * Returns whether the current provider is a service provider relatively to another provider. It
+ * uses the #LassoProfile.identity to find if a federation qualifier by the given provider exists or
+ * the reverse.
+ *
+ * Return value: #LASSO_PROVIDER_ROLE_NONE if nothing can be said, #LASSO_PROVIDER_ROLE_SP if a
+ * federation qualifier by @remote_provider_id exists or #LASSO_PROVIDER_ROLE_IDP if a federation
+ * qualifier by our own #LassoProvider.providerID exists.
+ */
+LassoProviderRole lasso_profile_sso_role_with(LassoProfile *profile, const char *remote_provider_id)
+{
+	LassoFederation *federation = NULL;
+	const char *name_qualifier = NULL;
+	const char *provider_id = NULL;
+
+
+	g_return_val_if_fail(LASSO_IS_PROFILE(profile) && remote_provider_id,
+			LASSO_PROVIDER_ROLE_NONE);
+
+	if (profile->server) {
+		provider_id = profile->server->parent.ProviderID;
+	}
+
+	federation = lasso_identity_get_federation(profile->identity, remote_provider_id);
+	if (! federation)
+		return LASSO_PROVIDER_ROLE_NONE;
+
+	/* coherency check */
+	g_return_val_if_fail(lasso_strisequal(federation->remote_providerID,remote_provider_id),
+			LASSO_PROVIDER_ROLE_NONE);
+
+	if (LASSO_IS_SAML2_NAME_ID(federation->local_nameIdentifier)) {
+		LassoSaml2NameID *name_id = (LassoSaml2NameID*)federation->local_nameIdentifier;
+		name_qualifier = name_id->NameQualifier;
+	} else if (LASSO_IS_SAML_NAME_IDENTIFIER(federation->local_nameIdentifier)) {
+		LassoSamlNameIdentifier *name_id;
+
+		name_id = (LassoSamlNameIdentifier*)federation->local_nameIdentifier;
+		name_qualifier = name_id->NameQualifier;
+	} else {
+		message(G_LOG_LEVEL_WARNING, "a federation without a NameID was found");
+		return LASSO_PROVIDER_ROLE_NONE;
+	}
+	if (lasso_strisequal(remote_provider_id,name_qualifier)) {
+		return LASSO_PROVIDER_ROLE_SP;
+	} else if (lasso_strisequal(provider_id,name_qualifier)) {
+		return LASSO_PROVIDER_ROLE_IDP;
+	}
+	return LASSO_PROVIDER_ROLE_NONE;
+}
+
+/**
+ * lasso_profile_get_signature_status:
+ * @profile: a #LassoProfile object
+ *
+ * Returns the signature status from the last parsed message.
+ *
+ * Return value: 0 if no error from signature checking occurred, an error code otherwise.
+ */
+gint
+lasso_profile_get_signature_status(LassoProfile *profile)
+{
+	lasso_bad_param(PROFILE, profile);
+
+	return profile->signature_status;
+}
 
 /*****************************************************************************/
 /* overridden parent class methods                                           */
@@ -509,20 +803,18 @@ dispose(GObject *object)
 	}
 	profile->private_data->dispose_has_run = TRUE;
 
-	lasso_server_destroy(profile->server);
-	profile->server = NULL;
 
-	lasso_identity_destroy(profile->identity);
-	profile->identity = NULL;
+	lasso_mem_debug("LassoProfile", "Server", profile->server);
+	lasso_release_gobject(profile->server);
 
-	lasso_session_destroy(profile->session);
-	profile->session = NULL;
+	lasso_mem_debug("LassoProfile", "Identity", profile->identity);
+	lasso_release_gobject(profile->identity);
 
-	g_free(profile->private_data->artifact);
-	profile->private_data->artifact = NULL;
+	lasso_mem_debug("LassoProfile", "Session", profile->session);
+	lasso_release_gobject(profile->session);
 
-	g_free(profile->private_data->artifact_message);
-	profile->private_data->artifact_message = NULL;
+	lasso_release_string(profile->private_data->artifact);
+	lasso_release_string(profile->private_data->artifact_message);
 
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(profile));
 }
@@ -531,7 +823,7 @@ static void
 finalize(GObject *object)
 {
 	LassoProfile *profile = LASSO_PROFILE(object);
-	g_free(profile->private_data);
+	lasso_release(profile->private_data);
 	G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
@@ -542,10 +834,11 @@ finalize(GObject *object)
 static void
 instance_init(LassoProfile *profile)
 {
-	profile->private_data = g_new(LassoProfilePrivate, 1);
+	profile->private_data = g_new0(LassoProfilePrivate, 1);
 	profile->private_data->dispose_has_run = FALSE;
 	profile->private_data->artifact = NULL;
 	profile->private_data->artifact_message = NULL;
+	profile->private_data->signature_hint = LASSO_PROFILE_SIGNATURE_HINT_MAYBE;
 
 	profile->server = NULL;
 	profile->request = NULL;
@@ -594,6 +887,7 @@ lasso_profile_get_type()
 			sizeof(LassoProfile),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
