@@ -1,22 +1,22 @@
-/* $Id: profileprivate.h 3324 2007-06-19 11:16:17Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -28,17 +28,17 @@
 #ifdef __cplusplus
 extern "C" {
 
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/id-ff/profile.h>
-
-#include <lasso/xml/soap_envelope.h>
+#include "profile.h"
 
 struct _LassoProfilePrivate
 {
 	char *artifact;
 	char *artifact_message;
 	gboolean dispose_has_run;
+	LassoProfileSignatureHint signature_hint;
+	LassoProfileSignatureVerifyHint signature_verify_hint;
 };
 
 void lasso_profile_set_response_status(LassoProfile *profile, const gchar *statusCodeValue);
