@@ -1,22 +1,22 @@
-/* $Id: server.c 3723 2008-05-21 12:35:54Z dlaniel $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -30,47 +30,38 @@
  * certificates to use, etc.
  **/
 
+#include "../xml/private.h"
 #include <xmlsec/base64.h>
 
-#include <lasso/lasso_config.h>
-#include <lasso/id-ff/server.h>
-
-#include <lasso/id-ff/providerprivate.h>
-#include <lasso/id-ff/serverprivate.h>
-
-#include <lasso/saml-2.0/serverprivate.h>
-
+#include <config.h>
+#include "server.h"
+#include "providerprivate.h"
+#include "serverprivate.h"
+#include "../saml-2.0/serverprivate.h"
+#include "../utils.h"
+#include "../debug.h"
+#include "../lasso_config.h"
 #ifdef LASSO_WSF_ENABLED
-#include <lasso/id-wsf-2.0/server.h>
-#include <lasso/xml/id-wsf-2.0/disco_service_context.h>
+#include "../id-wsf/id_ff_extensions_private.h"
+#include "../id-wsf-2.0/serverprivate.h"
 #endif
 
 /*****************************************************************************/
 /* public methods                                                            */
 /*****************************************************************************/
 
-/**
- * lasso_server_add_provider:
- * @server: a #LassoServer
- * @role: provider role, identity provider or service provider
- * @metadata: path to the provider metadata file
- * @public_key: provider public key file (may be a certificate) or NULL
- * @ca_cert_chain: provider CA certificate chain file or NULL
- * 
- * Creates a new #LassoProvider and makes it known to the @server
- * 
- * Return value: 0 on success; a negative value if an error occured.
- **/
-gint
-lasso_server_add_provider(LassoServer *server, LassoProviderRole role,
-		const gchar *metadata, const gchar *public_key, const gchar *ca_cert_chain)
+static gint
+lasso_server_add_provider_helper(LassoServer *server, LassoProviderRole role,
+		const gchar *metadata, const gchar *public_key, const gchar *ca_cert_chain,
+		LassoProvider *(*provider_constructor)(LassoProviderRole role,
+		const char *metadata, const char *public_key, const char *ca_cert_chain))
 {
 	LassoProvider *provider;
 
 	g_return_val_if_fail(LASSO_IS_SERVER(server), LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
 	g_return_val_if_fail(metadata != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
-	provider = lasso_provider_new(role, metadata, public_key, ca_cert_chain);
+	provider = provider_constructor(role, metadata, public_key, ca_cert_chain);
 	if (provider == NULL) {
 		return critical_error(LASSO_SERVER_ERROR_ADD_PROVIDER_FAILED);
 	}
@@ -93,119 +84,46 @@ lasso_server_add_provider(LassoServer *server, LassoProviderRole role,
 	return 0;
 }
 
-
 /**
- * lasso_server_add_service:
+ * lasso_server_add_provider:
  * @server: a #LassoServer
- * @service:
- * 
- * ...
- * 
+ * @role: provider role, identity provider or service provider
+ * @metadata: path to the provider metadata file
+ * @public_key:(allow-none): provider public key file (may be a certificate) or NULL
+ * @ca_cert_chain:(allow-none): provider CA certificate chain file or NULL
+ *
+ * Creates a new #LassoProvider and makes it known to the @server
+ *
  * Return value: 0 on success; a negative value if an error occured.
  **/
 gint
-lasso_server_add_service(LassoServer *server, LassoNode *service)
+lasso_server_add_provider(LassoServer *server, LassoProviderRole role,
+		const gchar *metadata, const gchar *public_key, const gchar *ca_cert_chain)
 {
-#ifdef LASSO_WSF_ENABLED
-	g_return_val_if_fail(LASSO_IS_SERVER(server), LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-	g_return_val_if_fail(service != NULL, LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-
-	if (LASSO_IS_DISCO_SERVICE_INSTANCE(service)) {
-		g_hash_table_insert(server->services,
-				g_strdup(LASSO_DISCO_SERVICE_INSTANCE(service)->ServiceType),
-				g_object_ref(service));
-	} else if (LASSO_IS_IDWSF2_DISCO_SVC_METADATA(service)) {
-		return lasso_server_add_svc_metadata(server,
-				LASSO_IDWSF2_DISCO_SVC_METADATA(service));
-	} else {
-		return LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ;
-	}
-#endif
-	return 0;
+	return lasso_server_add_provider_helper(server, role, metadata,
+			public_key, ca_cert_chain, lasso_provider_new);
 }
 
-
+/**
+ * lasso_server_add_provider_from_buffer:
+ * @server: a #LassoServer
+ * @role: provider role, identity provider or service provider
+ * @metadata: a string buffer containg the metadata file for a new provider
+ * @public_key:(allow-none): provider public key file (may be a certificate) or NULL
+ * @ca_cert_chain:(allow-none): provider CA certificate chain file or NULL
+ *
+ * Creates a new #LassoProvider and makes it known to the @server
+ *
+ * Return value: 0 on success; a negative value if an error occured.
+ **/
 gint
-lasso_server_add_service_from_dump(LassoServer *server, const gchar *dump)
+lasso_server_add_provider_from_buffer(LassoServer *server, LassoProviderRole role,
+		const gchar *metadata, const gchar *public_key, const gchar *ca_cert_chain)
 {
-	LassoNode *node;
-	gint return_code;
-
-	g_return_val_if_fail(dump != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
-
-	node = lasso_node_new_from_dump(dump);
-
-	return_code = lasso_server_add_service(server, node);
-
-	g_object_unref(node);
-
-	return return_code;
+	return lasso_server_add_provider_helper(server, role, metadata,
+			public_key, ca_cert_chain, lasso_provider_new_from_buffer);
 }
 
-#ifdef LASSO_WSF_ENABLED
-gint
-lasso_server_add_svc_metadata(LassoServer *server, LassoIdWsf2DiscoSvcMetadata *metadata)
-{
-
-	g_return_val_if_fail(LASSO_IS_SERVER(server), LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-	g_return_val_if_fail(LASSO_IS_IDWSF2_DISCO_SVC_METADATA(metadata),
-			LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-
-	server->private_data->svc_metadatas = g_list_append(
-		server->private_data->svc_metadatas, g_object_ref(metadata));
-
-	return 0;
-}
-
-const GList *
-lasso_server_get_svc_metadatas(LassoServer *server)
-{
-	g_return_val_if_fail(LASSO_IS_SERVER(server), NULL);
-
-	return server->private_data->svc_metadatas;
-}
-
-/* XXX: return value must be freed by caller */
-GList *
-lasso_server_get_svc_metadatas_with_id_and_type(LassoServer *server, GList *svcMDIDs,
-	const gchar *service_type)
-{
-	gchar *svcMDID;
-	LassoIdWsf2DiscoSvcMetadata *md;
-	GList *result = NULL;
-	GList *i;
-	GList *j;
-
-	g_return_val_if_fail(LASSO_IS_SERVER(server), NULL);
-	g_return_val_if_fail(service_type != NULL, NULL);
-
-	for (i = g_list_first(server->private_data->svc_metadatas); i != NULL; i = g_list_next(i)) {
-		md = LASSO_IDWSF2_DISCO_SVC_METADATA(i->data);
-		/* FIXME: this assumes there is one and only one service
-		 * context, and service type, this should be fixed to iterate
-		 * properly on the GList */
-		if (md->ServiceContext == NULL || strcmp((char*)(LASSO_IDWSF2_DISCO_SERVICE_CONTEXT(
-				md->ServiceContext->data)->ServiceType)->data, service_type) != 0) {
-			continue;
-		}
-		if (svcMDIDs == NULL) {
-			/* If no svcMDID is given, return all the metadatas with given */
-			/* service type */
-			result = g_list_append(result, g_object_ref(md));
-		} else {
-			for (j = g_list_first(svcMDIDs); j != NULL; j = g_list_next(j)) {
-				svcMDID = (gchar *)(j->data);
-				if (strcmp(svcMDID, md->svcMDID) == 0) {
-					result = g_list_append(result, g_object_ref(md));
-				}
-			}
-		}
-	}
-
-	return result;
-}
-#endif
-
 
 /**
  * lasso_server_destroy:
@@ -223,34 +141,56 @@ lasso_server_destroy(LassoServer *server)
 /**
  * lasso_server_set_encryption_private_key:
  * @server: a #LassoServer
- * @filename: file name of the encryption key to load
+ * @filename_or_buffer:(allow-none): file name of the encryption key to load or its content as a
+ * NULL-terminated string.
  *
  * Load an encryption private key from a file and set it in the server object
  *
+ * If @filename_or_buffer is NULL, it frees the currently setted key.
+ *
  * Return value: 0 on success; another value if an error occured.
+ * Deprecated: 2.3: Use lasso_server_set_encryption_private_key_with_password() instead.
  **/
 int
-lasso_server_set_encryption_private_key(LassoServer *server, const gchar *filename)
+lasso_server_set_encryption_private_key(LassoServer *server, const gchar *filename_or_buffer)
 {
-	LassoPemFileType file_type;
+	return lasso_server_set_encryption_private_key_with_password(server, filename_or_buffer,
+			NULL);
+}
 
-	if (server->private_data->encryption_private_key != NULL) {
-		xmlSecKeyDestroy(server->private_data->encryption_private_key);
-		server->private_data->encryption_private_key = NULL;
+/**
+ * lasso_server_set_encryption_private_key_with_password:
+ * @server: a #LassoServer
+ * @filename_or_buffer:(allow-none): file name of the encryption key to load or its content as a
+ * NULL-terminated string.
+ * @password:(allow-none): an optional password to decrypt the encryption key.
+ *
+ * Load an encryption private key from a file and set it in the server object. If @password is
+ * non-NULL try to decrypt the key with it.
+ *
+ * If @filename_or_buffer is NULL, it frees the currently setted key.
+ *
+ * Return value: 0 on success; another value if an error occured.
+ * Since: 2.3
+ **/
+int
+lasso_server_set_encryption_private_key_with_password(LassoServer *server,
+		const gchar *filename_or_buffer, const gchar *password)
+{
+	if (filename_or_buffer) {
+		xmlSecKey *key = lasso_xmlsec_load_private_key(filename_or_buffer, password);
+		if (! key || ! (xmlSecKeyGetType(key) & xmlSecKeyDataTypePrivate)) {
+			return LASSO_SERVER_ERROR_SET_ENCRYPTION_PRIVATE_KEY_FAILED;
+		}
+		lasso_release_sec_key(server->private_data->encryption_private_key);
+		server->private_data->encryption_private_key = key;
+	} else {
+		lasso_release_sec_key(server->private_data->encryption_private_key);
 	}
-	file_type = lasso_get_pem_file_type(filename);
-	if (file_type == LASSO_PEM_FILE_TYPE_PRIVATE_KEY) {
-		server->private_data->encryption_private_key = xmlSecCryptoAppKeyLoad(filename,
-			xmlSecKeyDataFormatPem, NULL, NULL, NULL);
-	}
-
-	if (server->private_data->encryption_private_key == NULL)
-		return LASSO_SERVER_ERROR_SET_ENCRYPTION_PRIVATE_KEY_FAILED;
 
 	return 0;
 }
 
-
 /**
  * lasso_server_load_affiliation:
  * @server: a #LassoServer
@@ -267,28 +207,22 @@ lasso_server_load_affiliation(LassoServer *server, const gchar *filename)
 	LassoProvider *provider = LASSO_PROVIDER(server);
 	xmlDoc *doc;
 	xmlNode *node;
-	int rc;
+	int rc = 0;
 
-	doc = xmlParseFile(filename);
-	if (doc == NULL) {
-		return LASSO_XML_ERROR_INVALID_FILE;
-	}
+	doc = lasso_xml_parse_file(filename);
+	goto_cleanup_if_fail_with_rc (doc != NULL, LASSO_XML_ERROR_INVALID_FILE);
 
 	node = xmlDocGetRootElement(doc);
-	if (node == NULL || node->ns == NULL) {
-		xmlFreeDoc(doc);
-		return LASSO_XML_ERROR_NODE_NOT_FOUND;
-	}
+	goto_cleanup_if_fail_with_rc (node != NULL && node->ns != NULL, LASSO_XML_ERROR_NODE_NOT_FOUND);
 
 	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
-		rc = lasso_saml20_server_load_affiliation(server, doc, node);
+		rc = lasso_saml20_server_load_affiliation(server, node);
 	} else {
 		/* affiliations are not supported in ID-FF 1.2 mode */
 		rc = LASSO_ERROR_UNIMPLEMENTED;
 	}
-
-	xmlFreeDoc(doc);
-
+cleanup:
+	lasso_release_doc(doc);
 	return rc;
 }
 
@@ -297,34 +231,21 @@ lasso_server_load_affiliation(LassoServer *server, const gchar *filename)
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "PrivateKeyFilePath", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoServer, private_key) },
+	{ "PrivateKeyFilePath", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoServer, private_key), NULL, NULL, NULL},
 	{ "PrivateKeyPassword", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoServer, private_key_password) },
-	{ "CertificateFilePath", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoServer, certificate) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoServer, private_key_password), NULL, NULL, NULL},
+	{ "CertificateFilePath", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoServer, certificate), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
 
 static void
-add_provider_childnode(gchar *key, LassoProvider *value, xmlNode *xmlnode)
+add_provider_childnode(G_GNUC_UNUSED gchar *key, LassoProvider *value, xmlNode *xmlnode)
 {
 	xmlAddChild(xmlnode, lasso_node_get_xmlNode(LASSO_NODE(value), TRUE));
 }
 
-#ifdef LASSO_WSF_ENABLED
-static void
-add_service_childnode(gchar *key, LassoNode *value, xmlNode *xmlnode)
-{
-	xmlAddChild(xmlnode, lasso_node_get_xmlNode(LASSO_NODE(value), TRUE));
-}
-
-static void
-add_childnode_from_list(LassoNode *value, xmlNode *xmlnode)
-{
-	xmlAddChild(xmlnode, lasso_node_get_xmlNode(LASSO_NODE(value), TRUE));
-}
-#endif
 
 static xmlNode*
 get_xmlNode(LassoNode *node, gboolean lasso_dump)
@@ -347,21 +268,8 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 	}
 
 #ifdef LASSO_WSF_ENABLED
-	/* Services */
-	if (g_hash_table_size(server->services)) {
-		xmlNode *t;
-		t = xmlNewTextChild(xmlnode, NULL, (xmlChar*)"Services", NULL);
-		g_hash_table_foreach(server->services,
-				(GHFunc)add_service_childnode, t);
-	}
-
-	/* Service Metadatas (SvcMD) */
-	if (server->private_data->svc_metadatas != NULL) {
-		xmlNode *t;
-		t = xmlNewTextChild(xmlnode, NULL, (xmlChar*)"SvcMDs", NULL);
-		g_list_foreach(server->private_data->svc_metadatas,
-				(GFunc)add_childnode_from_list, t);
-	}
+	lasso_server_dump_id_wsf_services(server, xmlnode);
+	lasso_server_dump_id_wsf20_svcmds(server, xmlnode);
 #endif
 
 	xmlCleanNs(xmlnode);
@@ -376,9 +284,14 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 	LassoServer *server = LASSO_SERVER(node);
 	xmlNode *t;
 	xmlChar *s;
-	int rc;
+	int rc = 0;
 
 	rc = parent_class->init_from_xml(node, xmlnode);
+
+	if (server->private_key) {
+		server->private_data->encryption_private_key =
+			lasso_xmlsec_load_private_key(server->private_key, server->private_key_password);
+	}
 	if (rc)
 		return rc;
 
@@ -420,38 +333,10 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 				t2 = t2->next;
 			}
 		}
-		
-#ifdef LASSO_WSF_ENABLED
-		/* Services */
-		if (strcmp((char*)t->name, "Services") == 0) {
-			while (t2) {
-				LassoDiscoServiceInstance *s;
-				if (t2->type != XML_ELEMENT_NODE) {
-					t2 = t2->next;
-					continue;
-				}
-				s = g_object_new(LASSO_TYPE_DISCO_SERVICE_INSTANCE, NULL);
-				LASSO_NODE_GET_CLASS(s)->init_from_xml(LASSO_NODE(s), t2);
-				g_hash_table_insert(server->services, g_strdup(s->ServiceType), s);
-				t2 = t2->next;
-			}
-		}
 
-		/* Service Metadatas (SvcMD) */		
-		if (strcmp((char*)t->name, "SvcMDs") == 0) {
-			while (t2) {
-				LassoIdWsf2DiscoSvcMetadata *svcMD;
-				if (t2->type != XML_ELEMENT_NODE) {
-					t2 = t2->next;
-					continue;
-				}
-				svcMD = lasso_idwsf2_disco_svc_metadata_new();
-				LASSO_NODE_GET_CLASS(svcMD)->init_from_xml(LASSO_NODE(svcMD), t2);
-				server->private_data->svc_metadatas = g_list_append(
-					server->private_data->svc_metadatas, svcMD);
-				t2 = t2->next;
-			}
-		}
+#ifdef LASSO_WSF_ENABLED
+		lasso_server_init_id_wsf_services(server, t);
+		lasso_server_init_id_wsf20_svcmds(server, t);
 #endif
 
 		t = t->next;
@@ -462,20 +347,53 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 
 
 static gboolean
-get_first_providerID(gchar *key, gpointer value, char **providerID)
+get_first_providerID(gchar *key, G_GNUC_UNUSED gpointer value, char **providerID)
 {
 	*providerID = key;
 	return TRUE;
 }
 
+static gboolean
+get_first_providerID_by_role(G_GNUC_UNUSED gchar *key, gpointer value, LassoProviderRole role) {
+	LassoProvider *provider = (LassoProvider*)value;
+	if (provider->role == role || role == LASSO_PROVIDER_ROLE_ANY) {
+		return TRUE;
+	}
+	return FALSE;
+}
+
+/**
+ * lasso_server_get_first_providerID_by_role
+ * @server: a #LassoServer
+ * @role: the #LassoProviderRole of the researched provider
+ *
+ * Looks up and returns the provider ID of known provider with the given role.
+ *
+ * Return value: the provider ID, NULL if there are no providers. This string
+ *     must be freed by the caller.
+ */
+gchar *
+lasso_server_get_first_providerID_by_role(const LassoServer *server, LassoProviderRole role)
+{
+	LassoProvider *a_provider;
+	a_provider = LASSO_PROVIDER(g_hash_table_find(server->providers,
+		(GHRFunc) get_first_providerID_by_role,
+		(gpointer)role));
+	if (a_provider) {
+		return g_strdup(a_provider->ProviderID);
+	} else {
+		return NULL;
+	}
+}
+
 /**
  * lasso_server_get_first_providerID:
  * @server: a #LassoServer
  *
  * Looks up and returns the provider ID of a known provider
  *
- * Return value: the provider ID, NULL if there are no providers.  This string
- *      must be freed by the caller.
+ * Return value:(transfer full)(allow-none): the provider ID, NULL if there are no providers.  This
+ * string must be freed by the caller.
  **/
 gchar*
 lasso_server_get_first_providerID(LassoServer *server)
@@ -494,36 +412,21 @@ lasso_server_get_first_providerID(LassoServer *server)
  *
  * Looks up for a #LassoProvider whose ID is @providerID and returns it.
  *
- * Return value: the #LassoProvider, NULL if it was not found.  The
+ * Return value: (transfer none): the #LassoProvider, NULL if it was not found.  The
  *     #LassoProvider is owned by Lasso and should not be freed.
  **/
 LassoProvider*
-lasso_server_get_provider(LassoServer *server, const gchar *providerID)
+lasso_server_get_provider(const LassoServer *server, const gchar *providerID)
 {
+	if (! LASSO_IS_SERVER(server) || providerID == NULL || strlen(providerID) == 0) {
+		return NULL;
+	}
 	return g_hash_table_lookup(server->providers, providerID);
 }
 
 
-/**
- * lasso_server_get_service:
- * @server: a #LassoServer
- * @serviceType:
- *
- * ...
- *
- * Return value: the #LassoDiscoServiceInstance, NULL if it was not found.
- *     The #LassoDiscoServiceInstance is owned by Lasso and should not be
- *     freed.
- **/
-LassoDiscoServiceInstance*
-lasso_server_get_service(LassoServer *server, const gchar *serviceType)
-{
-	return g_hash_table_lookup(server->services, serviceType);
-}
-
-
 static gboolean
-get_providerID_with_hash(gchar *key, gpointer value, char **providerID)
+get_providerID_with_hash(gchar *key, G_GNUC_UNUSED gpointer value, char **providerID)
 {
 	char *hash = *providerID;
 	xmlChar *hash_providerID;
@@ -552,7 +455,7 @@ get_providerID_with_hash(gchar *key, gpointer value, char **providerID)
  * Looks up a #LassoProvider whose ID hash is @b64_hash and returns its
  * provider ID.
  *
- * Return value: the provider ID, NULL if it was not found.
+ * Return value:(transfer full)(allow-none): the provider ID, NULL if it was not found.
  **/
 gchar*
 lasso_server_get_providerID_from_hash(LassoServer *server, gchar *b64_hash)
@@ -573,26 +476,20 @@ dispose(GObject *object)
 {
 	LassoServer *server = LASSO_SERVER(object);
 
-	if (server->private_data->dispose_has_run == TRUE) {
+	if (! server->private_data || server->private_data->dispose_has_run == TRUE) {
 		return;
 	}
 	server->private_data->dispose_has_run = TRUE;
 
-	/* FIXME : Probably necessary, must be tested */
-/* 	if (server->private_data->encryption_private_key != NULL) { */
-/* 		xmlSecKeyDestroy(server->private_data->encryption_private_key); */
-/* 		server->private_data->encryption_private_key = NULL; */
-/* 	} */
+	lasso_release_sec_key(server->private_data->encryption_private_key);
 
-	if (server->private_data->svc_metadatas != NULL) {
-		g_list_foreach(server->private_data->svc_metadatas, (GFunc)g_object_unref, NULL);
-		g_list_free(server->private_data->svc_metadatas);
-		server->private_data->svc_metadatas = NULL;
-	}
+	lasso_release_list_of_gobjects(server->private_data->svc_metadatas);
+
+	lasso_release_ghashtable(server->services);
 
 	/* free allocated memory for hash tables */
-	g_hash_table_destroy(server->providers);
-	server->providers = NULL;
+	lasso_mem_debug("LassoServer", "Providers", server->providers);
+	lasso_release_ghashtable(server->providers);
 
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(server));
 }
@@ -603,16 +500,16 @@ finalize(GObject *object)
 	LassoServer *server = LASSO_SERVER(object);
 	int i = 0;
 
-	g_free(server->private_key);
+	lasso_release(server->private_key);
 	if (server->private_key_password) {
 		/* don't use memset() because it may be optimised away by
-		 * compiler (since the string is freeed just after */
+		 * compiler (since the string is freed just after */
 		while (server->private_key_password[i])
 			server->private_key_password[i++] = 0;
-		g_free(server->private_key_password);
+		lasso_release(server->private_key_password);
 	}
-	g_free(server->certificate);
-	g_free(server->private_data);
+	lasso_release(server->certificate);
+	lasso_release(server->private_data);
 
 	G_OBJECT_CLASS(parent_class)->finalize(G_OBJECT(server));
 }
@@ -624,14 +521,14 @@ finalize(GObject *object)
 static void
 instance_init(LassoServer *server)
 {
-	server->private_data = g_new(LassoServerPrivate, 1);
+	server->private_data = g_new0(LassoServerPrivate, 1);
 	server->private_data->dispose_has_run = FALSE;
 	server->private_data->encryption_private_key = NULL;
 	server->private_data->svc_metadatas = NULL;
 
 	server->providers = g_hash_table_new_full(
 			g_str_hash, g_str_equal, g_free,
-			(GDestroyNotify)lasso_node_destroy);
+			g_object_unref);
 
 	server->private_key = NULL;
 	server->private_key_password = NULL;
@@ -640,14 +537,14 @@ instance_init(LassoServer *server)
 
 	server->services = g_hash_table_new_full(g_str_hash, g_str_equal,
 			(GDestroyNotify)g_free,
-			(GDestroyNotify)lasso_node_destroy);
+			g_object_unref);
 }
 
 static void
 class_init(LassoServerClass *klass)
 {
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
-	
+
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "Server");
@@ -677,6 +574,7 @@ lasso_server_get_type()
 			sizeof(LassoServer),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_PROVIDER,
@@ -688,20 +586,20 @@ lasso_server_get_type()
 /**
  * lasso_server_new:
  * @metadata: path to the provider metadata file or NULL, for a LECP server
- * @private_key: path to the the server private key file or NULL
- * @private_key_password: password to private key if it is encrypted, or NULL
- * @certificate: path to the server certificate file, or NULL
- * 
+ * @private_key:(allow-none): path to the the server private key file or NULL
+ * @private_key_password:(allow-none): password to private key if it is encrypted, or NULL
+ * @certificate:(allow-none): path to the server certificate file, or NULL
+ *
  * Creates a new #LassoServer.
- * 
+ *
  * Return value: a newly created #LassoServer object; or NULL if an error
  *      occured
  **/
 LassoServer*
 lasso_server_new(const gchar *metadata,
-		 const gchar *private_key,
-		 const gchar *private_key_password,
-		 const gchar *certificate)
+		const gchar *private_key,
+		const gchar *private_key_password,
+		const gchar *certificate)
 {
 	LassoServer *server;
 
@@ -717,13 +615,69 @@ lasso_server_new(const gchar *metadata,
 		}
 	}
 
-	server->private_key = g_strdup(private_key);
-	server->private_key_password = g_strdup(private_key_password);
-	server->certificate = g_strdup(certificate);
+	lasso_assign_string(server->certificate, certificate);
+	if (private_key) {
+		lasso_assign_string(server->private_key, private_key);
+		lasso_assign_string(server->private_key_password, private_key_password);
+		server->private_data->encryption_private_key = lasso_xmlsec_load_private_key(private_key,
+				private_key_password);
+		if (! server->private_data->encryption_private_key) {
+			message(G_LOG_LEVEL_WARNING, "Cannot load the private key");
+			lasso_release_gobject(server);
+		}
+	}
+	lasso_provider_load_public_key(&server->parent, LASSO_PUBLIC_KEY_SIGNING);
+	lasso_provider_load_public_key(&server->parent, LASSO_PUBLIC_KEY_ENCRYPTION);
 
 	return server;
 }
 
+/**
+ * lasso_server_new_from_buffers:
+ * @metadata: NULL terminated string containing the content of an ID-FF 1.2 metadata file
+ * @private_key_content:(allow-none): NULL terminated string containing a PEM formatted private key
+ * @private_key_password:(allow-none): a NULL terminated string which is the optional password of
+ * the private key
+ * @certificate_content:(allow-none): NULL terminated string containing a PEM formatted X509
+ * certificate
+ *
+ * Creates a new #LassoServer.
+ *
+ * Return value: a newly created #LassoServer object; or NULL if an error occured
+ */
+LassoServer*
+lasso_server_new_from_buffers(const char *metadata, const char *private_key_content, const char
+		*private_key_password, const char *certificate_content)
+{
+	LassoServer *server;
+
+	server = g_object_new(LASSO_TYPE_SERVER, NULL);
+	/* metadata can be NULL (if server is a LECP) */
+	if (metadata != NULL) {
+		if (lasso_provider_load_metadata_from_buffer(LASSO_PROVIDER(server), metadata) == FALSE) {
+			message(G_LOG_LEVEL_CRITICAL,
+					"Failed to load metadata from preloaded buffer");
+			lasso_node_destroy(LASSO_NODE(server));
+			return NULL;
+		}
+	}
+	lasso_assign_string(server->certificate, certificate_content);
+	if (private_key_content) {
+		lasso_assign_string(server->private_key, private_key_content);
+		lasso_assign_string(server->private_key_password, private_key_password);
+		server->private_data->encryption_private_key =
+			lasso_xmlsec_load_private_key_from_buffer(private_key_content,
+					strlen(private_key_content), private_key_password);
+		if (! server->private_data->encryption_private_key) {
+			message(G_LOG_LEVEL_WARNING, "Cannot load the private key");
+			lasso_release_gobject(server);
+		}
+	}
+	lasso_provider_load_public_key(&server->parent, LASSO_PUBLIC_KEY_SIGNING);
+	lasso_provider_load_public_key(&server->parent, LASSO_PUBLIC_KEY_ENCRYPTION);
+
+	return server;
+}
 /**
  * lasso_server_new_from_dump:
  * @dump: XML server dump
@@ -735,16 +689,13 @@ lasso_server_new(const gchar *metadata,
 LassoServer*
 lasso_server_new_from_dump(const gchar *dump)
 {
-	LassoNode *server;
-	server = lasso_node_new_from_dump(dump);
-	if (server == NULL)
-		return NULL;
+	LassoServer *server;
 
-	if (LASSO_IS_SERVER(server) == FALSE) {
-		lasso_node_destroy(LASSO_NODE(server));
-		return NULL;
+	server = (LassoServer*)lasso_node_new_from_dump(dump);
+	if (! LASSO_IS_SERVER(server)) {
+		lasso_release_gobject(server);
 	}
-	return LASSO_SERVER(server);
+	return server;
 }
 
 /**
@@ -753,10 +704,47 @@ lasso_server_new_from_dump(const gchar *dump)
  *
  * Dumps @server content to an XML string.
  *
- * Return value: the dump string.  It must be freed by the caller.
+ * Return value:(transfer full): the dump string.  It must be freed by the caller.
  **/
 gchar*
 lasso_server_dump(LassoServer *server)
 {
 	return lasso_node_dump(LASSO_NODE(server));
 }
+
+/**
+ * lasso_server_get_private_key:
+ * @server: a #LassoServer object
+ *
+ * Return value:(transfer full): a newly created #xmlSecKey object.
+ */
+xmlSecKey*
+lasso_server_get_private_key(LassoServer *server)
+{
+	if (! LASSO_IS_SERVER(server))
+		return NULL;
+
+	if (! server->private_key)
+		return NULL;
+
+	return lasso_xmlsec_load_private_key(server->private_key, server->private_key_password);
+}
+
+/**
+ * lasso_server_get_encryption_private_key:
+ * @server: a #LassoServer object
+ *
+ * Return:(transfer none): a xmlSecKey object, it is owned by the #LassoServer object, so do not
+ * free it.
+ */
+xmlSecKey*
+lasso_server_get_encryption_private_key(LassoServer *server)
+{
+	if (! LASSO_IS_SERVER(server))
+		return NULL;
+
+	if (! server->private_data)
+		return NULL;
+
+	return server->private_data->encryption_private_key;
+}
