@@ -1,34 +1,36 @@
-/* $Id: server.c 3237 2007-05-30 17:17:45Z dlaniel $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/saml-2.0/serverprivate.h>
-#include <lasso/id-ff/serverprivate.h>
-#include <lasso/id-ff/providerprivate.h>
+#include "../utils.h"
+#include "../xml/private.h"
+#include "serverprivate.h"
+#include "../id-ff/serverprivate.h"
+#include "../id-ff/providerprivate.h"
 
 
-int 
-lasso_saml20_server_load_affiliation(LassoServer *server, xmlDoc *doc, xmlNode *node)
+int
+lasso_saml20_server_load_affiliation(LassoServer *server, xmlNode *node)
 {
 	xmlNode *t;
 	char *owner_id, *member_id, *affiliation_id;
@@ -40,7 +42,7 @@ lasso_saml20_server_load_affiliation(LassoServer *server, xmlDoc *doc, xmlNode *
 	}
 
 	for (t = node->children; t; t = t->next) {
-		if (t->type == XML_ELEMENT_NODE && 
+		if (t->type == XML_ELEMENT_NODE &&
 				strcmp((char*)t->name, "AffiliationDescriptor") == 0) {
 			break;
 		}
@@ -55,7 +57,7 @@ lasso_saml20_server_load_affiliation(LassoServer *server, xmlDoc *doc, xmlNode *
 	owner_id = (char*)xmlGetProp(t, (xmlChar*)"affiliationOwnerID");
 
 	for (t = t->children; t; t = t->next) {
-		if (t->type == XML_ELEMENT_NODE && 
+		if (t->type == XML_ELEMENT_NODE &&
 				strcmp((char*)t->name, "AffiliateMember") == 0) {
 			member_id = (char*)xmlNodeGetContent(t);
 			provider = lasso_server_get_provider(server, member_id);
@@ -69,7 +71,7 @@ lasso_saml20_server_load_affiliation(LassoServer *server, xmlDoc *doc, xmlNode *
 				message(G_LOG_LEVEL_WARNING,
 						"Provider %s in more than one affiliation",
 						provider->ProviderID);
-				g_free(provider->private_data->affiliation_owner_id);
+				lasso_release_string(provider->private_data->affiliation_owner_id);
 			}
 			provider->private_data->affiliation_owner_id = g_strdup(owner_id);
 			provider->private_data->affiliation_id = g_strdup(affiliation_id);
