@@ -1,22 +1,22 @@
-/* $Id: disco_authenticate_session_context.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,9 +27,9 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "xml.h"
 
 #define LASSO_TYPE_DISCO_AUTHENTICATE_SESSION_CONTEXT \
 	(lasso_disco_authenticate_session_context_get_type())
@@ -45,10 +45,11 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass),LASSO_TYPE_DISCO_AUTHENTICATE_SESSION_CONTEXT))
 #define LASSO_DISCO_AUTHENTICATE_SESSION_CONTEXT_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), \
-	 LASSO_TYPE_DISCO_AUTHENTICATE_SESSION_CONTEXT, LassoDiscoAuthenticateSessionContextClass)) 
+	 LASSO_TYPE_DISCO_AUTHENTICATE_SESSION_CONTEXT, LassoDiscoAuthenticateSessionContextClass))
 
 typedef struct _LassoDiscoAuthenticateSessionContext LassoDiscoAuthenticateSessionContext;
-typedef struct _LassoDiscoAuthenticateSessionContextClass LassoDiscoAuthenticateSessionContextClass;
+typedef struct _LassoDiscoAuthenticateSessionContextClass
+	LassoDiscoAuthenticateSessionContextClass;
 
 struct _LassoDiscoAuthenticateSessionContext {
 	LassoNode parent;
@@ -65,9 +66,6 @@ LASSO_EXPORT GType lasso_disco_authenticate_session_context_get_type(void);
 LASSO_EXPORT LassoDiscoAuthenticateSessionContext* \
 	lasso_disco_authenticate_session_context_new(void);
 
-LASSO_EXPORT LassoDiscoAuthenticateSessionContext* \
-	lasso_disco_authenticate_session_context_new_from_message(const gchar *message);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
