@@ -1,28 +1,30 @@
-/* $Id: disco_resource_id.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/disco_resource_id.h>
+#include "private.h"
+#include "disco_resource_id.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:disco_resource_id
@@ -30,7 +32,7 @@
  *
  * <figure><title>Schema fragment for disco:ResourceID</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <xs:element name="ResourceID" type="ResourceIDType"/>
  * <xs:complexType name="ResourceIDType">
  *     <xs:simpleContent>
@@ -48,22 +50,15 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoDiscoResourceID, id) },
-	{ "", SNIPPET_TEXT_CHILD, G_STRUCT_OFFSET(LassoDiscoResourceID, content) },
-	{ NULL, 0, 0}
+	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoDiscoResourceID, id), NULL, NULL, NULL},
+	{ "", SNIPPET_TEXT_CHILD, G_STRUCT_OFFSET(LassoDiscoResourceID, content), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoDiscoResourceID *node)
-{
-	node->id = NULL;
-	node->content = NULL;
-}
-
 static void
 class_init(LassoDiscoResourceIDClass *klass)
 {
@@ -90,7 +85,8 @@ lasso_disco_resource_id_get_type()
 			NULL,
 			sizeof(LassoDiscoResourceID),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
