@@ -1,31 +1,34 @@
-/* $Id: ds_rsa_key_value.c 3237 2007-05-30 17:17:45Z dlaniel $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/ds_rsa_key_value.h>
+#include "private.h"
+#include "ds_rsa_key_value.h"
 
 /*
- * 
+ * SECTION:ds_rsa_key_value
+ * @short_description: Object representation of an XML DSIG element to hold an RSA key
+ *
  */
 
 /*****************************************************************************/
@@ -33,21 +36,15 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "Modulus", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoDsRsaKeyValue, Modulus) },
-	{ "Exponent", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoDsRsaKeyValue, Exponent) },
-	{ NULL, 0, 0}
+	{ "Modulus", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoDsRsaKeyValue, Modulus), NULL, NULL, NULL},
+	{ "Exponent", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoDsRsaKeyValue, Exponent), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoDsRsaKeyValue *node)
-{
-	node->Modulus = NULL;
-	node->Exponent = NULL;
-}
 
 static void
 class_init(LassoDsRsaKeyValueClass *klass)
@@ -75,7 +72,8 @@ lasso_ds_rsa_key_value_get_type()
 			NULL,
 			sizeof(LassoDsRsaKeyValue),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -86,9 +84,9 @@ lasso_ds_rsa_key_value_get_type()
 
 /**
  * lasso_ds_rsa_key_value_new:
- * 
+ *
  * Creates a new #LassoDsRsaKeyValue object.
- * 
+ *
  * Return value: a newly created #LassoDsRsaKeyValue object
  **/
 LassoDsRsaKeyValue*
