@@ -1,22 +1,22 @@
-/* $Id: dst_query_response.h 3437 2007-11-03 21:23:50Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,11 +27,11 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/dst_data.h>
-#include <lasso/xml/utility_status.h>
-#include <lasso/xml/xml.h>
+#include "dst_data.h"
+#include "utility_status.h"
+#include "xml.h"
 
 #define LASSO_TYPE_DST_QUERY_RESPONSE (lasso_dst_query_response_get_type())
 #define LASSO_DST_QUERY_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
@@ -53,7 +53,7 @@ struct _LassoDstQueryResponse {
 
 	/*< public >*/
 	LassoUtilityStatus *Status;
-	GList *Data;
+	GList *Data; /* of LassoNode */
 	GList *Extension; /* of xmlNode* */
 
 	char *id;
