@@ -1,28 +1,30 @@
-/* $Id: disco_service_context.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: disco_service_context.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "disco_service_context.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:disco_service_context
@@ -50,14 +52,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "ServiceType", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2DiscoServiceContext, ServiceType) },
+		G_STRUCT_OFFSET(LassoIdWsf2DiscoServiceContext, ServiceType), NULL, NULL, NULL},
 	{ "Options", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DiscoServiceContext, Options),
-		"LassoIdWsf2DiscoOptions" },
+		"LassoIdWsf2DiscoOptions", NULL, NULL },
 	{ "EndpointContext", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DiscoServiceContext, EndpointContext),
-		"LassoIdWsf2DiscoEndpointContext" },
-	{NULL, 0, 0}
+		"LassoIdWsf2DiscoEndpointContext", NULL, NULL },
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -67,13 +69,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2DiscoServiceContext *node)
-{
-	node->ServiceType = NULL;
-	node->Options = NULL;
-	node->EndpointContext = NULL;
-}
 
 static void
 class_init(LassoIdWsf2DiscoServiceContextClass *klass)
@@ -83,7 +78,7 @@ class_init(LassoIdWsf2DiscoServiceContextClass *klass)
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "ServiceContext");
-	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCO_HREF, LASSO_IDWSF2_DISCO_PREFIX);
+	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCOVERY_HREF, LASSO_IDWSF2_DISCOVERY_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
 
@@ -102,7 +97,8 @@ lasso_idwsf2_disco_service_context_get_type()
 			NULL,
 			sizeof(LassoIdWsf2DiscoServiceContext),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
