@@ -1,28 +1,30 @@
-/* $Id: disco_svc_md_register_response.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: disco_svc_md_register_response.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "disco_svc_md_register_response.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:disco_svc_md_register_response
@@ -33,11 +35,11 @@
  *
  * <xs:complexType name="SvcMDRegisterResponseType">
  *   <xs:sequence>
- *     
+ *
  *     <xs:element ref="lu:Status" />
  *     <xs:element ref="SvcMDID"   minOccurs="0" maxOccurs="unbounded" />
  *     <xs:element ref="Keys"      minOccurs="0" maxOccurs="unbounded" />
- *     
+ *
  *   </xs:sequence>
  *   <xs:anyAttribute namespace="##other" processContents="lax"/>
  * </xs:complexType>
@@ -53,15 +55,15 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "Status", SNIPPET_NODE,
 		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, Status),
-		"LassoIdWsf2UtilStatus" },
+		"LassoIdWsf2UtilStatus", NULL, NULL },
 	{ "SvcMDID", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, SvcMDID) },
+		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, SvcMDID), NULL, NULL, NULL},
 	{ "Keys", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, Keys),
-		"LassoIdWsf2DiscoKeys" },
+		"LassoIdWsf2DiscoKeys", NULL, NULL },
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegisterResponse, attributes), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -74,9 +76,6 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2DiscoSvcMDRegisterResponse *node)
 {
-	node->Status = NULL;
-	node->SvcMDID = NULL;
-	node->Keys = NULL;
 	node->attributes = g_hash_table_new_full(
 		g_str_hash, g_str_equal, g_free, g_free);
 }
@@ -89,7 +88,7 @@ class_init(LassoIdWsf2DiscoSvcMDRegisterResponseClass *klass)
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "SvcMDRegisterResponse");
-	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCO_HREF, LASSO_IDWSF2_DISCO_PREFIX);
+	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCOVERY_HREF, LASSO_IDWSF2_DISCOVERY_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
 
@@ -109,6 +108,7 @@ lasso_idwsf2_disco_svc_md_register_response_get_type()
 			sizeof(LassoIdWsf2DiscoSvcMDRegisterResponse),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
