@@ -1,28 +1,30 @@
-/* $Id: dstref_create.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: dstref_create.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "dstref_create.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:dstref_create
@@ -53,11 +55,11 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "CreateItem", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DstRefCreate, CreateItem),
-		"LassoIdWsf2DstRefCreateItem" },
+		"LassoIdWsf2DstRefCreateItem", NULL, NULL },
 	{ "ResultQuery", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DstRefCreate, ResultQuery),
-		"LassoIdWsf2DstRefResultQuery" },
-	{NULL, 0, 0}
+		"LassoIdWsf2DstRefResultQuery", NULL, NULL },
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -67,12 +69,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2DstRefCreate *node)
-{
-	node->CreateItem = NULL;
-	node->ResultQuery = NULL;
-}
 
 static void
 class_init(LassoIdWsf2DstRefCreateClass *klass)
@@ -101,7 +97,8 @@ lasso_idwsf2_dstref_create_get_type()
 			NULL,
 			sizeof(LassoIdWsf2DstRefCreate),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_DST_REQUEST,
