@@ -1,28 +1,30 @@
-/* $Id: dstref_item_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: dstref_item_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "dstref_item_data.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:dstref_item_data
@@ -49,12 +51,12 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "itemIDRef", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, itemIDRef) },
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, itemIDRef), NULL, NULL, NULL},
 	{ "notSorted", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, notSorted) },
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, notSorted), NULL, NULL, NULL},
 	{ "changeFormat", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, changeFormat) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefItemData, changeFormat), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -64,13 +66,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2DstRefItemData *node)
-{
-	node->itemIDRef = NULL;
-	node->notSorted = NULL;
-	node->changeFormat = NULL;
-}
 
 static void
 class_init(LassoIdWsf2DstRefItemDataClass *klass)
@@ -99,7 +94,8 @@ lasso_idwsf2_dstref_item_data_get_type()
 			NULL,
 			sizeof(LassoIdWsf2DstRefItemData),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_DSTREF_APP_DATA,
