@@ -1,22 +1,22 @@
-/* $Id: dstref_modify_item.h,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: dstref_modify_item.h,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -29,7 +29,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "../xml.h"
 #include "dstref_app_data.h"
 
 #define LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM (lasso_idwsf2_dstref_modify_item_get_type())
@@ -50,7 +50,7 @@ extern "C" {
 #define LASSO_IDWSF2_DSTREF_MODIFY_ITEM_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), \
 		LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM, \
-		LassoIdWsf2DstRefModifyItemClass)) 
+		LassoIdWsf2DstRefModifyItemClass))
 
 
 typedef struct _LassoIdWsf2DstRefModifyItem LassoIdWsf2DstRefModifyItem;
