@@ -1,28 +1,30 @@
-/* $Id: is_inquiry_element.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: is_inquiry_element.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "is_inquiry_element.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:is_inquiry_element
@@ -51,16 +53,16 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Help", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Help) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Help), NULL, NULL, NULL},
 	{ "Hint", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Hint) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Hint), NULL, NULL, NULL},
 	{ "Label", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Label) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Label), NULL, NULL, NULL},
 	{ "Value", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Value) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, Value), NULL, NULL, NULL},
 	{ "name", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, name) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiryElement, name), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -70,15 +72,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2IsInquiryElement *node)
-{
-	node->Help = NULL;
-	node->Hint = NULL;
-	node->Label = NULL;
-	node->Value = NULL;
-	node->name = NULL;
-}
 
 static void
 class_init(LassoIdWsf2IsInquiryElementClass *klass)
@@ -107,7 +100,8 @@ lasso_idwsf2_is_inquiry_element_get_type()
 			NULL,
 			sizeof(LassoIdWsf2IsInquiryElement),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
