@@ -1,28 +1,30 @@
-/* $Id: is_interaction_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: is_interaction_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "is_interaction_request.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:is_interaction_request
@@ -52,18 +54,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Inquiry", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, Inquiry) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, Inquiry), NULL, NULL, NULL},
 	{ "KeyInfo", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, KeyInfo) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, KeyInfo), NULL, NULL, NULL},
 	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, id) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, id), NULL, NULL, NULL},
 	{ "language", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, language) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, language), NULL, NULL, NULL},
 	{ "maxInteractTime", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, maxInteractTime) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, maxInteractTime), NULL, NULL, NULL},
 	{ "signed", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, signed_) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2IsInteractionRequest, signed_), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -73,16 +75,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2IsInteractionRequest *node)
-{
-	node->Inquiry = NULL;
-	node->KeyInfo = NULL;
-	node->id = NULL;
-	node->language = NULL;
-	node->maxInteractTime = 0;
-	node->signed_ = NULL;
-}
 
 static void
 class_init(LassoIdWsf2IsInteractionRequestClass *klass)
@@ -111,7 +103,8 @@ lasso_idwsf2_is_interaction_request_get_type()
 			NULL,
 			sizeof(LassoIdWsf2IsInteractionRequest),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
