@@ -1,28 +1,30 @@
-/* $Id: ps_add_entity_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: ps_add_entity_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "ps_add_entity_request.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:ps_add_entity_request
@@ -55,16 +57,16 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Object", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, Object) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, Object), NULL, NULL, NULL},
 	{ "PStoSPRedirectURL", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, PStoSPRedirectURL) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, PStoSPRedirectURL), NULL, NULL, NULL},
 	{ "CreatePSObject", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, CreatePSObject) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, CreatePSObject), NULL, NULL, NULL},
 	{ "Subscription", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, Subscription) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, Subscription), NULL, NULL, NULL},
 	{ "TokenPolicy", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, TokenPolicy) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2PsAddEntityRequest, TokenPolicy), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -74,15 +76,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2PsAddEntityRequest *node)
-{
-	node->Object = NULL;
-	node->PStoSPRedirectURL = NULL;
-	node->CreatePSObject = NULL;
-	node->Subscription = NULL;
-	node->TokenPolicy = NULL;
-}
 
 static void
 class_init(LassoIdWsf2PsAddEntityRequestClass *klass)
@@ -111,7 +104,8 @@ lasso_idwsf2_ps_add_entity_request_get_type()
 			NULL,
 			sizeof(LassoIdWsf2PsAddEntityRequest),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_PS_REQUEST_ABSTRACT,
