@@ -1,28 +1,30 @@
-/* $Id: sb2_consent.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: sb2_consent.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "sb2_consent.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:sb2_consent
@@ -47,12 +49,12 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "uri", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, uri) },
+		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, uri), NULL, NULL, NULL},
 	{ "timestamp", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, timestamp) },
+		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, timestamp), NULL, NULL, NULL},
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2Sb2Consent, attributes), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -65,8 +67,6 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2Sb2Consent *node)
 {
-	node->uri = NULL;
-	node->timestamp = NULL;
 	node->attributes = g_hash_table_new_full(
 		g_str_hash, g_str_equal, g_free, g_free);
 }
@@ -99,6 +99,7 @@ lasso_idwsf2_sb2_consent_get_type()
 			sizeof(LassoIdWsf2Sb2Consent),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
