@@ -1,28 +1,30 @@
-/* $Id: sb2_redirect_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: sb2_redirect_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "sb2_redirect_request.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:sb2_redirect_request
@@ -45,8 +47,8 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "redirectURL", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2Sb2RedirectRequest, redirectURL) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2Sb2RedirectRequest, redirectURL), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -56,11 +58,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2Sb2RedirectRequest *node)
-{
-	node->redirectURL = NULL;
-}
 
 static void
 class_init(LassoIdWsf2Sb2RedirectRequestClass *klass)
@@ -89,7 +86,8 @@ lasso_idwsf2_sb2_redirect_request_get_type()
 			NULL,
 			sizeof(LassoIdWsf2Sb2RedirectRequest),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
