@@ -1,28 +1,30 @@
-/* $Id: sec_token_policy.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: sec_token_policy.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "sec_token_policy.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:sec_token_policy
@@ -52,18 +54,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "", SNIPPET_NODE | SNIPPET_ANY | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, any) },
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, any), NULL, NULL, NULL},
 	{ "validUntil", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, validUntil) },
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, validUntil), NULL, NULL, NULL},
 	{ "issueTo", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, issueTo) },
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, issueTo), NULL, NULL, NULL},
 	{ "type", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, type) },
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, type), NULL, NULL, NULL},
 	{ "wantDSEPR", SNIPPET_ATTRIBUTE | SNIPPET_BOOLEAN | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, wantDSEPR) },
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, wantDSEPR), NULL, NULL, NULL},
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2SecTokenPolicy, attributes), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -76,11 +78,6 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2SecTokenPolicy *node)
 {
-	node->any = NULL;
-	node->validUntil = NULL;
-	node->issueTo = NULL;
-	node->type = NULL;
-	node->wantDSEPR = FALSE;
 	node->attributes = g_hash_table_new_full(
 		g_str_hash, g_str_equal, g_free, g_free);
 }
@@ -113,6 +110,7 @@ lasso_idwsf2_sec_token_policy_get_type()
 			sizeof(LassoIdWsf2SecTokenPolicy),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
