@@ -1,28 +1,30 @@
-/* $Id: subs_notification.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: subs_notification.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "subs_notification.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:subs_notification
@@ -52,16 +54,16 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "TestResult", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, TestResult),
-		"LassoIdWsf2UtilTestResult" },
+		"LassoIdWsf2UtilTestResult", NULL, NULL },
 	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, id) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, id), NULL, NULL, NULL},
 	{ "subscriptionID", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, subscriptionID) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, subscriptionID), NULL, NULL, NULL},
 	{ "expires", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, expires) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, expires), NULL, NULL, NULL},
 	{ "endReason", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, endReason) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2SubsNotification, endReason), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -71,15 +73,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2SubsNotification *node)
-{
-	node->TestResult = NULL;
-	node->id = NULL;
-	node->subscriptionID = NULL;
-	node->expires = NULL;
-	node->endReason = NULL;
-}
 
 static void
 class_init(LassoIdWsf2SubsNotificationClass *klass)
@@ -108,7 +101,8 @@ lasso_idwsf2_subs_notification_get_type()
 			NULL,
 			sizeof(LassoIdWsf2SubsNotification),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
