@@ -1,28 +1,31 @@
-/* $Id: subsref_app_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: subsref_app_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "subsref_app_data.h"
+#include "./idwsf2_strings.h"
+#include "../../registry.h"
 
 /**
  * SECTION:subsref_app_data
@@ -37,10 +40,10 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "", SNIPPET_LIST_XMLNODES,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefAppData, any) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefAppData, any), NULL, NULL, NULL},
 	{ "Subscription", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefAppData, Subscription) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefAppData, Subscription), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -50,12 +53,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2SubsRefAppData *node)
-{
-	node->any = NULL;
-	node->Subscription = NULL;
-}
 
 static void
 class_init(LassoIdWsf2SubsRefAppDataClass *klass)
@@ -84,11 +81,14 @@ lasso_idwsf2_subsref_app_data_get_type()
 			NULL,
 			sizeof(LassoIdWsf2SubsRefAppData),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
 				"LassoIdWsf2SubsRefAppData", &this_info, 0);
+		lasso_registry_default_add_direct_mapping(LASSO_IDWSF2_SUBSREF_HREF, "NewData",
+				LASSO_LASSO_HREF, "LassoIdWsf2SubsRefAppData");
 	}
 	return this_type;
 }
