@@ -1,28 +1,30 @@
-/* $Id: subsref_create_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: subsref_create_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "subsref_create_item.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:subsref_create_item
@@ -48,14 +50,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "NewData", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, NewData) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, NewData), NULL, NULL, NULL},
 	{ "objectType", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, objectType) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, objectType), NULL, NULL, NULL},
 	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, id) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, id), NULL, NULL, NULL},
 	{ "itemID", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, itemID) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefCreateItem, itemID), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -65,14 +67,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2SubsRefCreateItem *node)
-{
-	node->NewData = NULL;
-	node->objectType = NULL;
-	node->id = NULL;
-	node->itemID = NULL;
-}
 
 static void
 class_init(LassoIdWsf2SubsRefCreateItemClass *klass)
@@ -101,7 +95,8 @@ lasso_idwsf2_subsref_create_item_get_type()
 			NULL,
 			sizeof(LassoIdWsf2SubsRefCreateItem),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
