@@ -1,28 +1,30 @@
-/* $Id: subsref_query_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: subsref_query_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "subsref_query_item.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:subsref_query_item
@@ -49,14 +51,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "count", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_OPTIONAL_NEG,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, count) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, count), NULL, NULL, NULL},
 	{ "offset", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_OPTIONAL_NEG,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, offset) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, offset), NULL, NULL, NULL},
 	{ "setID", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, setID) },
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, setID), NULL, NULL, NULL},
 	{ "setReq", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, setReq) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2SubsRefQueryItem, setReq), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -71,8 +73,6 @@ instance_init(LassoIdWsf2SubsRefQueryItem *node)
 {
 	node->count = -1;
 	node->offset = -1;
-	node->setID = NULL;
-	node->setReq = NULL;
 }
 
 static void
@@ -103,6 +103,7 @@ lasso_idwsf2_subsref_query_item_get_type()
 			sizeof(LassoIdWsf2SubsRefQueryItem),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_SUBSREF_RESULT_QUERY,
