@@ -1,22 +1,22 @@
-/* $Id: is_interaction_request.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,12 +27,12 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/disco_encrypted_resource_id.h>
-#include <lasso/xml/disco_resource_id.h>
-#include <lasso/xml/is_inquiry.h>
-#include <lasso/xml/xml.h>
+#include "disco_encrypted_resource_id.h"
+#include "disco_resource_id.h"
+#include "is_inquiry.h"
+#include "xml.h"
 
 
 #define LASSO_TYPE_IS_INTERACTION_REQUEST (lasso_is_interaction_request_get_type())
@@ -58,7 +58,7 @@ struct _LassoIsInteractionRequest {
 
 	LassoDiscoResourceID *ResourceID;
 	LassoDiscoEncryptedResourceID *EncryptedResourceID;
-	GList *Inquiry;
+	GList *Inquiry; /* of LassoNode */
 	/* TODO : ds:KeyInfo */
 
 	char *id;
@@ -75,9 +75,6 @@ LASSO_EXPORT GType lasso_is_interaction_request_get_type(void);
 
 LASSO_EXPORT LassoIsInteractionRequest* lasso_is_interaction_request_new(void);
 
-LASSO_EXPORT LassoIsInteractionRequest* lasso_is_interaction_request_new_from_message(
-	const char *msg);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
