@@ -1,22 +1,22 @@
-/* $Id: is_interaction_response.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,10 +27,10 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/utility_status.h>
-#include <lasso/xml/xml.h>
+#include "utility_status.h"
+#include "xml.h"
 
 #define LASSO_TYPE_IS_INTERACTION_RESPONSE (lasso_is_interaction_response_get_type())
 #define LASSO_IS_INTERACTION_RESPONSE(obj) \
@@ -53,8 +53,8 @@ struct _LassoIsInteractionResponse {
 	LassoNode parent; /* FIXME : inherit of LassoIsInquiryElement */
 
 	LassoUtilityStatus *Status;
-	GList *InteractionStatement;
-	GList *Parameter;
+	GList *InteractionStatement; /* of LassoNode */
+	GList *Parameter; /* of LassoNode */
 };
 
 struct _LassoIsInteractionResponseClass {
@@ -65,9 +65,6 @@ LASSO_EXPORT GType lasso_is_interaction_response_get_type(void);
 
 LASSO_EXPORT LassoIsInteractionResponse* lasso_is_interaction_response_new();
 
-LASSO_EXPORT LassoIsInteractionResponse* lasso_is_interaction_response_new_from_message(
-	const char *msg);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
