@@ -1,28 +1,30 @@
-/* $Id: is_text.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/is_text.h>
+#include "private.h"
+#include "is_text.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:is_text
@@ -44,30 +46,23 @@
  *
  * ]]></programlisting>
  * </figure>
- */ 
+ */
 
 /*****************************************************************************/
 /* private methods                                                           */
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "minChars", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, minChars) },
-	{ "maxChars", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, maxChars) },
-	{ "format", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, format) },
-	{ NULL, 0, 0}
+	{ "minChars", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, minChars), NULL, NULL, NULL},
+	{ "maxChars", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, maxChars), NULL, NULL, NULL},
+	{ "format", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoIsText, format), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIsText *node)
-{
-	node->minChars = 0;
-	node->maxChars = 0;
-	node->format = NULL;
-}
 
 static void
 class_init(LassoIsTextClass *klass)
@@ -95,7 +90,8 @@ lasso_is_text_get_type()
 			NULL,
 			sizeof(LassoIsText),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
