@@ -1,28 +1,29 @@
-/* $Id: lib_idp_entries.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_idp_entries.h>
+#include "private.h"
+#include "lib_idp_entries.h"
 
 /**
  * SECTION:lib_idp_entries
@@ -47,19 +48,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "IDPEntry", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoLibIDPEntries, IDPEntry) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoLibIDPEntries, IDPEntry), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibIDPEntries *node)
-{
-	node->IDPEntry = NULL;
-}
 
 static void
 class_init(LassoLibIDPEntriesClass *klass)
@@ -87,7 +83,8 @@ lasso_lib_idp_entries_get_type()
 			NULL,
 			sizeof(LassoLibIDPEntries),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -98,9 +95,9 @@ lasso_lib_idp_entries_get_type()
 
 /**
  * lasso_lib_idp_entries_new:
- * 
+ *
  * Creates a new #LassoLibIDPEntries object.
- * 
+ *
  * Return value: a newly created #LassoLibIDPEntries object
  **/
 LassoNode*
