@@ -1,28 +1,29 @@
-/* $Id: lib_idp_list.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_idp_list.h>
+#include "private.h"
+#include "lib_idp_list.h"
 
 /**
  * SECTION:lib_idp_list
@@ -37,7 +38,7 @@
  *     <xs:element ref="GetComplete" minOccurs="0"/>
  *   </xs:sequence>
  * </xs:complexType>
- * 
+ *
  * <xs:element name="GetComplete" type="xs:anyURI"/>
  * ]]></programlisting>
  * </figure>
@@ -48,21 +49,15 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "IDPEntries", SNIPPET_NODE, G_STRUCT_OFFSET(LassoLibIDPList, IDPEntries) },
-	{ "GetComplete", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPList, GetComplete) },
-	{ NULL, 0, 0}
+	{ "IDPEntries", SNIPPET_NODE, G_STRUCT_OFFSET(LassoLibIDPList, IDPEntries), NULL, NULL, NULL},
+	{ "GetComplete", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPList, GetComplete), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibIDPList *node)
-{
-	node->IDPEntries = NULL;
-	node->GetComplete = NULL;
-}
 
 static void
 class_init(LassoLibIDPListClass *klass)
@@ -90,7 +85,8 @@ lasso_lib_idp_list_get_type()
 			NULL,
 			sizeof(LassoLibIDPList),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -101,7 +97,7 @@ lasso_lib_idp_list_get_type()
 
 /**
  * lasso_lib_idp_list_new:
- * 
+ *
  * Creates a new #LassoLibIDPList object.
  *
  * Return value: a newly created #LassoLibIDPList object
