@@ -1,28 +1,29 @@
-/* $Id: lib_name_identifier_mapping_request.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_name_identifier_mapping_request.h>
+#include "private.h"
+#include "lib_name_identifier_mapping_request.h"
 
 /**
  * SECTION:lib_name_identifier_mapping_request
@@ -44,7 +45,7 @@
  *     </xs:extension>
  *   </xs:complexContent>
  * </xs:complexType>
- * 
+ *
  * <xs:element name="ProviderID" type="md:entityIDType"/>
  * ]]></programlisting>
  * </figure>
@@ -56,31 +57,22 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Extension", SNIPPET_EXTENSION,
-		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, Extension) },
+		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, Extension), NULL, NULL, NULL},
 	{ "ProviderID", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, ProviderID) },
+		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, ProviderID), NULL, NULL, NULL},
 	{ "NameIdentifier", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, NameIdentifier) },
+		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, NameIdentifier), NULL, NULL, NULL},
 	{ "TargetNamespace", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, TargetNamespace) },
+		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, TargetNamespace), NULL, NULL, NULL},
 	{ "consent", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, consent) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoLibNameIdentifierMappingRequest, consent), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibNameIdentifierMappingRequest *node)
-{
-	node->Extension = NULL;
-	node->ProviderID = NULL;
-	node->NameIdentifier = NULL;
-	node->TargetNamespace = NULL;
-	node->consent = NULL;
-}
 
 static void
 class_init(LassoLibNameIdentifierMappingRequestClass *klass)
@@ -108,7 +100,8 @@ lasso_lib_name_identifier_mapping_request_get_type()
 			NULL,
 			sizeof(LassoLibNameIdentifierMappingRequest),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAMLP_REQUEST_ABSTRACT,
@@ -135,13 +128,14 @@ lasso_lib_name_identifier_mapping_request_new()
 /**
  * lasso_lib_name_identifier_mapping_request_new_full:
  * @providerID: the provider ID requesting the name identifier mapping
- * @nameIdentifier:
- * @targetNamespace:
- * @sign_type:
- * @sign_method:
+ * @nameIdentifier: a #LassoSamlNameIdentifier object
+ * @targetNamespace: an URI for the target namespace
+ * @sign_type: a #LassoSignatureType value
+ * @sign_method: a #LassoSignatureMethod value
  *
- * Creates a new #LassoLibNameIdentifierMappingRequest object and initializes
- * it with the parameters.
+ * Creates a new #LassoLibNameIdentifierMappingRequest object and initializes it with the
+ * parameters. It also setups the signature on the request object, you must preceise the signing key
+ * later.
  *
  * Return value: a newly created #LassoLibNameIdentifierMappingRequest object
  **/
@@ -163,7 +157,7 @@ lasso_lib_name_identifier_mapping_request_new_full(char *providerID,
 
 	/* ProviderID */
 	LASSO_LIB_NAME_IDENTIFIER_MAPPING_REQUEST(request)->ProviderID = g_strdup(providerID);
-	LASSO_LIB_NAME_IDENTIFIER_MAPPING_REQUEST(request)->NameIdentifier = 
+	LASSO_LIB_NAME_IDENTIFIER_MAPPING_REQUEST(request)->NameIdentifier =
 		g_object_ref(nameIdentifier);
 
 	LASSO_LIB_NAME_IDENTIFIER_MAPPING_REQUEST(request)->TargetNamespace =
