@@ -1,28 +1,29 @@
-/* $Id: lib_request_authn_context.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_request_authn_context.h>
+#include "private.h"
+#include "lib_request_authn_context.h"
 
 /**
  * SECTION:lib_request_authn_context
@@ -30,7 +31,7 @@
  *
  * Information describing which authentication context the requester desires the
  * identity provider to use in authenticating the Principal.
- * 
+ *
  * <figure><title>Schema fragment for lib:RequestAuthnContext</title>
  * <programlisting><![CDATA[
  * <xs:element name="RequestAuthnContext">
@@ -40,7 +41,7 @@
  *         <xs:element name="AuthnContextClassRef" type="xs:anyURI" maxOccurs="unbounded"/>
  *         <xs:element name="AuthnContextStatementRef" type="xs:anyURI" maxOccurs="unbounded"/>
  *       </xs:choice>
- *       <xs:element name="AuthnContextComparison" 
+ *       <xs:element name="AuthnContextComparison"
  *           type="AuthnContextComparisonType" minOccurs="0"/>
  *     </xs:sequence>
  *   </xs:complexType>
@@ -55,25 +56,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AuthnContextClassRef", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextClassRef) },
+		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextClassRef), NULL, NULL, NULL},
 	{ "AuthnContextStatementRef", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextStatementRef) },
+		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextStatementRef), NULL, NULL, NULL},
 	{ "AuthnContextComparison", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextComparison) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoLibRequestAuthnContext, AuthnContextComparison), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibRequestAuthnContext *node)
-{
-	node->AuthnContextClassRef = NULL;
-	node->AuthnContextStatementRef = NULL;
-	node->AuthnContextComparison = NULL;
-}
 
 static void
 class_init(LassoLibRequestAuthnContextClass *klass)
@@ -101,7 +95,8 @@ lasso_lib_request_authn_context_get_type()
 			NULL,
 			sizeof(LassoLibRequestAuthnContext),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
