@@ -1,22 +1,22 @@
-/* $Id: lib_request_authn_context.h 3435 2007-10-30 18:15:41Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,9 +27,9 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "xml.h"
 
 #define LASSO_TYPE_LIB_REQUEST_AUTHN_CONTEXT (lasso_lib_request_authn_context_get_type())
 #define LASSO_LIB_REQUEST_AUTHN_CONTEXT(obj) \
@@ -44,7 +44,7 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_LIB_REQUEST_AUTHN_CONTEXT))
 #define LASSO_LIB_REQUEST_AUTHN_CONTEXT_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_LIB_REQUEST_AUTHN_CONTEXT, \
-				    LassoLibRequestAuthnContextClass)) 
+				    LassoLibRequestAuthnContextClass))
 
 typedef struct _LassoLibRequestAuthnContext LassoLibRequestAuthnContext;
 typedef struct _LassoLibRequestAuthnContextClass LassoLibRequestAuthnContextClass;
@@ -57,7 +57,7 @@ struct _LassoLibRequestAuthnContext {
 	GList *AuthnContextClassRef; /* of strings */
 	/* <xs:element name="AuthnContextStatementRef" type="xs:anyURI" maxOccurs="unbounded"/> */
 	GList *AuthnContextStatementRef; /* of strings */
-	/* <xs:element name="AuthnContextComparison" type="AuthnContextComparisonType" 
+	/* <xs:element name="AuthnContextComparison" type="AuthnContextComparisonType"
 	 *   minOccurs="0"/> */
 	char *AuthnContextComparison;
 };
