@@ -1,28 +1,30 @@
-/* $Id: sa_sasl_response.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/sa_sasl_response.h>
+#include "private.h"
+#include "sa_sasl_response.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:sa_sasl_response
@@ -30,7 +32,7 @@
  *
  * <figure><title>Schema fragment for sa:SASLResponse</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <xs:element name="SASLResponse">
  * <xs:complexType>
  *   <xs:sequence>
@@ -51,7 +53,7 @@
  *       </xs:sequence>
  *     </xs:complexType>
  *     </xs:element>
- *   </xs:sequence> 
+ *   </xs:sequence>
  *   <xs:attribute name="serverMechanism" type="xs:string" ="optional"/>
  *   <xs:attribute name="id" type="xs:ID" use="optional"/>
  * </xs:complexType>
@@ -59,26 +61,26 @@
  *
  * ]]></programlisting>
  * </figure>
- */ 
+ */
 
 /*****************************************************************************/
 /* private methods                                                           */
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "Status", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSaSASLResponse, Status) },
+	{ "Status", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSaSASLResponse, Status), NULL, NULL, NULL},
 	{ "PasswordTransforms", SNIPPET_LIST_NODES,
-	  G_STRUCT_OFFSET(LassoSaSASLResponse, PasswordTransforms) },
+		G_STRUCT_OFFSET(LassoSaSASLResponse, PasswordTransforms), NULL, NULL, NULL},
 	{ "Data", SNIPPET_LIST_CONTENT,
-	  G_STRUCT_OFFSET(LassoSaSASLResponse, Data) },
+		G_STRUCT_OFFSET(LassoSaSASLResponse, Data), NULL, NULL, NULL},
 	{ "ResourceOffering", SNIPPET_LIST_NODES,
-	  G_STRUCT_OFFSET(LassoSaSASLResponse, ResourceOffering) },
-	{ "Credentials", SNIPPET_LIST_NODES, G_STRUCT_OFFSET(LassoSaSASLResponse, Credentials) },
+		G_STRUCT_OFFSET(LassoSaSASLResponse, ResourceOffering), NULL, NULL, NULL},
+	{ "Credentials", SNIPPET_LIST_NODES, G_STRUCT_OFFSET(LassoSaSASLResponse, Credentials), NULL, NULL, NULL},
 	{ "serverMechanism", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSaSASLResponse, serverMechanism) },
+		G_STRUCT_OFFSET(LassoSaSASLResponse, serverMechanism), NULL, NULL, NULL},
 	{ "id", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSaSASLResponse, id) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSaSASLResponse, id), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -113,18 +115,6 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSaSASLResponse *node)
-{
-	node->Status = NULL;
-	node->PasswordTransforms = NULL;
-	node->Data = NULL;
-	node->ResourceOffering = NULL;
-	node->Credentials = NULL;
-	node->any = NULL;
-	node->serverMechanism = NULL;
-	node->id = NULL;
-}
 
 static void
 class_init(LassoSaSASLResponseClass *klass)
@@ -153,7 +143,8 @@ lasso_sa_sasl_response_get_type()
 			NULL,
 			sizeof(LassoSaSASLResponse),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -174,46 +165,3 @@ lasso_sa_sasl_response_new(LassoUtilityStatus *status)
 
 	return node;
 }
-
-LassoSaSASLResponse*
-lasso_sa_sasl_response_new_from_message(const gchar *message)
-{
-	LassoSaSASLResponse *node;
-
-	g_return_val_if_fail(message != NULL, NULL);
-
-	node = g_object_new(LASSO_TYPE_SA_SASL_RESPONSE, NULL);
-	lasso_node_init_from_message(LASSO_NODE(node), message);
-
-	return node;
-}
-
-gint
-lasso_sa_sasl_response_add_credentials(LassoSaSASLResponse *response,
-				       LassoSaCredentials *credentials)
-{
-	g_return_val_if_fail(LASSO_IS_SA_SASL_RESPONSE(response),
-			     LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-	g_return_val_if_fail(LASSO_IS_SA_CREDENTIALS(credentials),
-			     LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-
-	g_object_ref(credentials);
-	response->Credentials = g_list_append(response->Credentials, credentials);
-
-	return 0;
-}
-
-gint
-lasso_sa_sasl_response_add_resource_offering(LassoSaSASLResponse *response,
-					     LassoDiscoResourceOffering *resourceOffering)
-{
-	g_return_val_if_fail(LASSO_IS_SA_SASL_RESPONSE(response),
-			     LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-	g_return_val_if_fail(LASSO_IS_DISCO_RESOURCE_OFFERING(resourceOffering),
-			     LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
-
-	g_object_ref(resourceOffering);
-	response->ResourceOffering = g_list_append(response->ResourceOffering, resourceOffering);
-
-	return 0;
-}
