@@ -1,30 +1,33 @@
-/* $Id: saml2_assertion.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 
+#include "../../utils.h"
+#include "../private.h"
 #include <xmlsec/xmldsig.h>
 #include <xmlsec/templates.h>
+#include <xmlsec/xmltree.h>
 
 #include "saml2_assertion.h"
 
@@ -65,73 +68,74 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "Issuer", SNIPPET_NODE,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, Issuer),
-		"LassoSaml2NameID" },
+		"LassoSaml2NameID", NULL, NULL},
 	{ "Signature", SNIPPET_SIGNATURE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, ID) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, ID), NULL, NULL, NULL},
 	{ "Subject", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, Subject) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, Subject), NULL, NULL, NULL},
 	{ "Conditions", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, Conditions) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, Conditions), NULL, NULL, NULL},
 	{ "Advice", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, Advice) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, Advice), NULL, NULL, NULL},
 	{ "Statement", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, Statement) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, Statement), NULL, NULL, NULL},
 	{ "AuthnStatement", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthnStatement) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthnStatement), NULL, NULL, NULL},
 	{ "AuthzDecisionStatement", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthzDecisionStatement) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthzDecisionStatement), NULL, NULL, NULL},
 	{ "AttributeStatement", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, AttributeStatement) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, AttributeStatement), NULL, NULL, NULL},
 	{ "Version", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, Version) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, Version), NULL, NULL, NULL},
 	{ "ID", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, ID) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, ID), NULL, NULL, NULL},
 	{ "IssueInstant", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, IssueInstant) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, IssueInstant), NULL, NULL, NULL},
 
 	/* hidden fields; used in lasso dumps */
 	{ "SignType", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, sign_type) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, sign_type), NULL, NULL, NULL},
 	{ "SignMethod", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, sign_method) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, sign_method), NULL, NULL, NULL},
 	{ "PrivateKeyFile", SNIPPET_CONTENT | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, private_key_file) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, private_key_file), NULL, NULL, NULL},
 	{ "CertificateFile", SNIPPET_CONTENT | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, certificate_file) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, certificate_file), NULL, NULL, NULL},
 	{ "EncryptionActivated", SNIPPET_ATTRIBUTE | SNIPPET_BOOLEAN | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_activated) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_activated), NULL, NULL, NULL},
 	{ "EncryptionPublicKeyStr", SNIPPET_CONTENT | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_public_key_str) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_public_key_str), NULL, NULL, NULL},
 	{ "EncryptionSymKeyType", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_sym_key_type) },
+		G_STRUCT_OFFSET(LassoSaml2Assertion, encryption_sym_key_type), NULL, NULL, NULL},
 
-	{NULL, 0, 0}
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
 
-
-
 static xmlNode*
 get_xmlNode(LassoNode *node, gboolean lasso_dump)
 {
-	LassoSaml2Assertion *request = LASSO_SAML2_ASSERTION(node);
-	xmlNode *xmlnode;
-	int rc;
-	
-	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
+	xmlNode *xmlnode, *original_xmlnode;
 
-	if (lasso_dump == FALSE && request->sign_type) {
-		if (request->private_key_file == NULL) {
-			message(G_LOG_LEVEL_WARNING,
-					"No Private Key set for signing samlp2:RequestAbstract");
-		} else {
-			rc = lasso_sign_node(xmlnode, "ID", request->ID,
-				request->private_key_file, request->certificate_file);
-			/* signature may have failed; what to do ? */
+	/* If assertion has been deserialized and contain a signature, dump it from the
+	 * original xmlnode. */
+	original_xmlnode = lasso_node_get_original_xmlnode(node);
+	while (original_xmlnode) {
+		xmlNode *signature, *signature_value;
+
+		signature = xmlSecFindChild(original_xmlnode, xmlSecNodeSignature, xmlSecDSigNs);
+		if (! signature)
+			break;
+		signature_value = xmlSecFindNode(signature, xmlSecNodeSignatureValue, xmlSecDSigNs);
+		if (signature_value && signature_value->children) {
+			return xmlCopyNode(original_xmlnode, 1);
 		}
+		break;
 	}
 
+	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
+
 	return xmlnode;
 }
 
@@ -143,22 +147,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 static void
 instance_init(LassoSaml2Assertion *node)
 {
-	node->Issuer = NULL;
-	node->Subject = NULL;
-	node->Conditions = NULL;
-	node->Advice = NULL;
-	node->Statement = NULL;
-	node->AuthnStatement = NULL;
-	node->AuthzDecisionStatement = NULL;
-	node->AttributeStatement = NULL;
-	node->Version = NULL;
-	node->ID = NULL;
-	node->IssueInstant = NULL;
 	node->sign_type = LASSO_SIGNATURE_TYPE_NONE;
-	node->private_key_file = NULL;
-	node->certificate_file = NULL;
-	node->encryption_activated = FALSE;
-	node->encryption_public_key_str = NULL;
 	node->encryption_sym_key_type = LASSO_ENCRYPTION_SYM_KEY_TYPE_DEFAULT;
 }
 
@@ -170,14 +159,21 @@ class_init(LassoSaml2AssertionClass *klass)
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->get_xmlNode = get_xmlNode;
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "Assertion"); 
-	lasso_node_class_set_ns(nclass, LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
+	lasso_node_class_set_nodename(nclass, "Assertion");
+	lasso_node_class_set_ns(nclass,LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 
+	nclass->node_data->id_attribute_name = "ID";
+	nclass->node_data->id_attribute_offset = G_STRUCT_OFFSET(LassoSaml2Assertion, ID);
 	nclass->node_data->sign_type_offset = G_STRUCT_OFFSET(
 			LassoSaml2Assertion, sign_type);
 	nclass->node_data->sign_method_offset = G_STRUCT_OFFSET(
 			LassoSaml2Assertion, sign_method);
+	nclass->node_data->private_key_file_offset = G_STRUCT_OFFSET(LassoSaml2Assertion,
+			private_key_file);
+	nclass->node_data->certificate_file_offset = G_STRUCT_OFFSET(LassoSaml2Assertion,
+			certificate_file);
+	nclass->node_data->keep_xmlnode = TRUE;
 }
 
 GType
@@ -196,6 +192,7 @@ lasso_saml2_assertion_get_type()
 			sizeof(LassoSaml2Assertion),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
