@@ -1,22 +1,22 @@
-/* $Id: saml2_attribute.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -29,7 +29,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "../xml.h"
 
 #define LASSO_TYPE_SAML2_ATTRIBUTE (lasso_saml2_attribute_get_type())
 #define LASSO_SAML2_ATTRIBUTE(obj) \
@@ -44,7 +44,7 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAML2_ATTRIBUTE))
 #define LASSO_SAML2_ATTRIBUTE_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAML2_ATTRIBUTE, \
-				LassoSaml2AttributeClass)) 
+				LassoSaml2AttributeClass))
 
 typedef struct _LassoSaml2Attribute LassoSaml2Attribute;
 typedef struct _LassoSaml2AttributeClass LassoSaml2AttributeClass;
@@ -55,7 +55,7 @@ struct _LassoSaml2Attribute {
 
 	/*< public >*/
 	/* elements */
-	GList *AttributeValue;
+	GList *AttributeValue; /* of LassoNode */
 	/* attributes */
 	char *Name;
 	char *NameFormat;
