@@ -1,27 +1,28 @@
-/* $Id: saml2_authn_context.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "saml2_authn_context.h"
 
 /**
@@ -59,15 +60,15 @@
 
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "AuthnContextClassRef", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextClassRef) },
-	{ "AuthnContextDecl", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextDecl) },
-	{ "AuthnContextDeclRef", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextDeclRef) },
-	{ "AuthenticatingAuthority", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthenticatingAuthority) },
-	{NULL, 0, 0}
+	{ "AuthnContextClassRef", SNIPPET_CONTENT | SNIPPET_OPTIONAL,
+		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextClassRef), NULL, NULL, NULL},
+	{ "AuthnContextDecl", SNIPPET_NODE | SNIPPET_OPTIONAL,
+		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextDecl), NULL, NULL, NULL},
+	{ "AuthnContextDeclRef", SNIPPET_CONTENT | SNIPPET_OPTIONAL,
+		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthnContextDeclRef), NULL, NULL, NULL},
+	{ "AuthenticatingAuthority", SNIPPET_CONTENT | SNIPPET_OPTIONAL,
+		G_STRUCT_OFFSET(LassoSaml2AuthnContext, AuthenticatingAuthority), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -77,14 +78,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSaml2AuthnContext *node)
-{
-	node->AuthnContextClassRef = NULL;
-	node->AuthnContextDecl = NULL;
-	node->AuthnContextDeclRef = NULL;
-	node->AuthenticatingAuthority = NULL;
-}
 
 static void
 class_init(LassoSaml2AuthnContextClass *klass)
@@ -93,7 +86,7 @@ class_init(LassoSaml2AuthnContextClass *klass)
 
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "AuthnContext"); 
+	lasso_node_class_set_nodename(nclass, "AuthnContext");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
@@ -113,7 +106,8 @@ lasso_saml2_authn_context_get_type()
 			NULL,
 			sizeof(LassoSaml2AuthnContext),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
