@@ -1,28 +1,30 @@
-/* $Id: samlp2_request_abstract.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 
+#include "../private.h"
+#include "../../utils.h"
 #include <xmlsec/xmldsig.h>
 #include <xmlsec/templates.h>
 
@@ -59,62 +61,56 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "Issuer", SNIPPET_NODE,
 		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Issuer),
-		"LassoSaml2NameID" },
+		"LassoSaml2NameID", NULL, NULL },
 	{ "Signature", SNIPPET_SIGNATURE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, ID) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, ID), NULL, NULL, NULL},
 	{ "Extensions", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Extensions) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Extensions), NULL, NULL, NULL},
 	{ "ID", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, ID) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, ID), NULL, NULL, NULL},
 	{ "Version", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Version) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Version), NULL, NULL, NULL},
 	{ "IssueInstant", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, IssueInstant) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, IssueInstant), NULL, NULL, NULL},
 	{ "Destination", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Destination) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Destination), NULL, NULL, NULL},
 	{ "Consent", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Consent) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, Consent), NULL, NULL, NULL},
 
 	/* hidden fields; used in lasso dumps */
 	{ "SignType", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, sign_type) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, sign_type), NULL, NULL, NULL},
 	{ "SignMethod", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, sign_method) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, sign_method), NULL, NULL, NULL},
 	{ "PrivateKeyFile", SNIPPET_CONTENT | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, private_key_file) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, private_key_file), NULL, NULL, NULL},
 	{ "CertificateFile", SNIPPET_CONTENT | SNIPPET_LASSO_DUMP,
-		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, certificate_file) },
+		G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, certificate_file), NULL, NULL, NULL},
 
-	{NULL, 0, 0}
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
 
-
-
-static xmlNode*
-get_xmlNode(LassoNode *node, gboolean lasso_dump)
+static gboolean
+init_from_query(LassoNode *node, char **query_fields)
 {
-	LassoSamlp2RequestAbstract *request = LASSO_SAMLP2_REQUEST_ABSTRACT(node);
-	xmlNode *xmlnode;
-	int rc;
-	
-	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
-
-	if (lasso_dump == FALSE && request->sign_type) {
-		if (request->private_key_file == NULL) {
-			message(G_LOG_LEVEL_WARNING,
-					"No Private Key set for signing samlp2:RequestAbstract");
-		} else {
-			rc = lasso_sign_node(xmlnode, "ID", request->ID,
-				request->private_key_file, request->certificate_file);
-			/* signature may have failed; what to do ? */
-		}
-	}
-
-	return xmlnode;
+	return lasso_node_init_from_saml2_query_fields(node, query_fields, NULL);
 }
 
+static gchar*
+build_query(LassoNode *node)
+{
+	char *ret, *deflated_message;
+
+	deflated_message = lasso_node_build_deflated_query(node);
+	if (deflated_message == NULL) {
+		return NULL;
+	}
+	ret = g_strdup_printf(LASSO_SAML2_FIELD_REQUEST "=%s", deflated_message);
+	lasso_release(deflated_message);
+	return ret;
+}
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
@@ -123,16 +119,7 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 static void
 instance_init(LassoSamlp2RequestAbstract *node)
 {
-	node->Issuer = NULL;
-	node->Extensions = NULL;
-	node->ID = NULL;
-	node->Version = NULL;
-	node->IssueInstant = NULL;
-	node->Destination = NULL;
-	node->Consent = NULL;
 	node->sign_type = LASSO_SIGNATURE_TYPE_NONE;
-	node->private_key_file = NULL;
-	node->certificate_file = NULL;
 }
 
 static void
@@ -141,16 +128,24 @@ class_init(LassoSamlp2RequestAbstractClass *klass)
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
 	parent_class = g_type_class_peek_parent(klass);
-	nclass->get_xmlNode = get_xmlNode;
+	nclass->build_query = build_query;
+	nclass->init_from_query = init_from_query;
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "RequestAbstract"); 
+	nclass->node_data->keep_xmlnode = TRUE;
+	lasso_node_class_set_nodename(nclass, "RequestAbstract");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 
+	nclass->node_data->id_attribute_name = "ID";
+	nclass->node_data->id_attribute_offset = G_STRUCT_OFFSET(LassoSamlp2RequestAbstract, ID);
 	nclass->node_data->sign_type_offset = G_STRUCT_OFFSET(
 			LassoSamlp2RequestAbstract, sign_type);
 	nclass->node_data->sign_method_offset = G_STRUCT_OFFSET(
 			LassoSamlp2RequestAbstract, sign_method);
+	nclass->node_data->private_key_file_offset = G_STRUCT_OFFSET(LassoSamlp2RequestAbstract,
+			private_key_file);
+	nclass->node_data->certificate_file_offset = G_STRUCT_OFFSET(LassoSamlp2RequestAbstract,
+			certificate_file);
 }
 
 GType
@@ -169,6 +164,7 @@ lasso_samlp2_request_abstract_get_type()
 			sizeof(LassoSamlp2RequestAbstract),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
