@@ -1,30 +1,32 @@
-/* $Id: samlp2_response.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "samlp2_response.h"
-#include "saml2_assertion.h"
-#include "saml2_encrypted_element.h"
+#include "../private.h"
+#include "./samlp2_response.h"
+#include "./saml2_assertion.h"
+#include "./saml2_encrypted_element.h"
+#include "../../utils.h"
 
 /**
  * SECTION:samlp2_response
@@ -47,74 +49,42 @@
  * </figure>
  */
 
-extern LassoNode* lasso_assertion_encrypt(LassoSaml2Assertion *assertion);
+extern LassoNode* lasso_assertion_encrypt(LassoSaml2Assertion *assertion, char *recipient);
 
 /*****************************************************************************/
 /* private methods                                                           */
 /*****************************************************************************/
 
-
 static struct XmlSnippet schema_snippets[] = {
 	{ "Assertion", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSamlp2Response, Assertion) },
+		G_STRUCT_OFFSET(LassoSamlp2Response, Assertion), NULL, NULL, NULL},
 	{ "EncryptedAssertion", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSamlp2Response, EncryptedAssertion) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlp2Response, EncryptedAssertion), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
 
-
-static gchar*
-build_query(LassoNode *node)
-{
-	char *ret, *deflated_message;
-
-	deflated_message = lasso_node_build_deflated_query(node);
-	if (deflated_message == NULL) {
-		return NULL;
-	}
-	ret = g_strdup_printf("SAMLResponse=%s", deflated_message);
-	/* XXX: must support RelayState (which profiles?) */
-	g_free(deflated_message);
-	return ret;
-}
-
-
-static gboolean
-init_from_query(LassoNode *node, char **query_fields)
-{
-	gboolean rc;
-	char *relay_state = NULL;
-	rc = lasso_node_init_from_saml2_query_fields(node, query_fields, &relay_state);
-	if (rc && relay_state != NULL) {
-		/* XXX: support RelayState? */
-	}
-	return rc;
-}
-
 static xmlNode*
 get_xmlNode(LassoNode *node, gboolean lasso_dump)
 {
 	LassoSamlp2Response *response = LASSO_SAMLP2_RESPONSE(node);
-	GList *assertions, *assertions_copy;
+	GList *assertions = NULL;
+	GList *Assertion_save = NULL;
 	LassoNode *encrypted_element = NULL;
-	xmlNode *result;
+	xmlNode *result = NULL;
 
 
 	/* Encrypt Assertions for messages but not for dumps */
 	if (lasso_dump == FALSE) {
-		assertions_copy = g_list_copy(response->Assertion);
-		for (assertions = response->Assertion;
-				assertions != NULL; assertions = g_list_next(assertions)) {
-			encrypted_element = lasso_assertion_encrypt(assertions->data);
+		Assertion_save = response->Assertion;
+		response->Assertion = NULL;
+		lasso_foreach (assertions, Assertion_save) {
+			encrypted_element = lasso_assertion_encrypt(assertions->data, NULL);
 			if (encrypted_element != NULL) {
-				/* use EncryptedAssertion */
-				response->EncryptedAssertion = g_list_append(
-					response->EncryptedAssertion, encrypted_element);
-				/* and remove original unencrypted from Assertion */
-				response->Assertion = g_list_remove(response->Assertion,
-					assertions->data);
+				lasso_list_add_new_gobject(response->EncryptedAssertion, encrypted_element);
+			} else {
+				lasso_list_add_gobject(response->Assertion, assertions->data);
 			}
 		}
 	}
@@ -122,14 +92,8 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 	result = parent_class->get_xmlNode(node, lasso_dump);
 
 	if (lasso_dump == FALSE) {
-		g_list_free(response->Assertion);
-		response->Assertion = assertions_copy;
-		for (assertions = response->EncryptedAssertion; assertions != NULL;
-				assertions = g_list_next(assertions)) {
-			lasso_node_destroy(assertions->data);
-		}
-		g_list_free(response->EncryptedAssertion);
-		response->EncryptedAssertion = NULL;
+		lasso_release_list_of_gobjects(response->EncryptedAssertion);
+		lasso_assign_new_list_of_gobjects(response->Assertion, Assertion_save);
 	}
 
 	return result;
@@ -139,12 +103,6 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlp2Response *node)
-{
-	node->Assertion = NULL;
-	node->EncryptedAssertion = NULL;
-}
 
 static void
 class_init(LassoSamlp2ResponseClass *klass)
@@ -152,11 +110,10 @@ class_init(LassoSamlp2ResponseClass *klass)
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
 	parent_class = g_type_class_peek_parent(klass);
-	nclass->build_query = build_query;
-	nclass->init_from_query = init_from_query;
 	nclass->get_xmlNode = get_xmlNode;
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "Response"); 
+	nclass->node_data->keep_xmlnode = TRUE;
+	lasso_node_class_set_nodename(nclass, "Response");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
@@ -176,7 +133,8 @@ lasso_samlp2_response_get_type()
 			NULL,
 			sizeof(LassoSamlp2Response),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAMLP2_STATUS_RESPONSE,
