@@ -1,27 +1,28 @@
-/* $Id: samlp2_status_code.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "samlp2_status_code.h"
 
 /**
@@ -48,10 +49,10 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "StatusCode", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSamlp2StatusCode, StatusCode) },
+		G_STRUCT_OFFSET(LassoSamlp2StatusCode, StatusCode), NULL, NULL, NULL},
 	{ "Value", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlp2StatusCode, Value) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlp2StatusCode, Value), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -61,12 +62,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlp2StatusCode *node)
-{
-	node->StatusCode = NULL;
-	node->Value = NULL;
-}
 
 static void
 class_init(LassoSamlp2StatusCodeClass *klass)
@@ -75,7 +70,7 @@ class_init(LassoSamlp2StatusCodeClass *klass)
 
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "StatusCode"); 
+	lasso_node_class_set_nodename(nclass, "StatusCode");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_PROTOCOL_HREF, LASSO_SAML2_PROTOCOL_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
@@ -95,7 +90,8 @@ lasso_samlp2_status_code_get_type()
 			NULL,
 			sizeof(LassoSamlp2StatusCode),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
