@@ -1,32 +1,38 @@
-/* $Id: saml_attribute.c 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_attribute.h>
+#include "private.h"
+#include "saml_attribute.h"
 
 /*
- * The schema fragment (oasis-sstc-saml-schema-assertion-1.1.xsd):
+ * SECTION:saml_attribute
+ * @short_description: Mapping of the SAML element containing an attribute
+ * @stability: Stable
  *
+ * The schema fragment (oasis-sstc-saml-schema-assertion-1.1.xsd):
+ * <figure><title>Schema fragment for saml:Attribute</title>
+ * <programlisting><![CDATA[
  * <element name="Attribute" type="saml:AttributeType"/>
  * <complexType name="AttributeType">
  *   <complexContent>
@@ -37,9 +43,9 @@
  *     </extension>
  *   </complexContent>
  * </complexType>
- * 
+ *
  * <element name="AttributeValue" type="anyType"/>
- * 
+ *
  * <xs:complexType name="anyType" mixed="true">
  *   <xs:annotation>
  *     <xs:documentation>
@@ -57,6 +63,8 @@
  *   <attribute name="AttributeName" type="string" use="required"/>
  *   <attribute name="AttributeNamespace" type="anyURI" use="required"/>
  * </complexType>
+ * ]]></programlisting>
+ * </figure>
  *
  */
 
@@ -66,25 +74,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AttributeName", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSamlAttribute, attributeName) },
+		G_STRUCT_OFFSET(LassoSamlAttribute, attributeName), NULL, NULL, NULL},
 	{ "AttributeNameSpace", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSamlAttribute, attributeNameSpace) },
+		G_STRUCT_OFFSET(LassoSamlAttribute, attributeNameSpace), NULL, NULL, NULL},
 	{ "AttributeValue", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSamlAttribute, AttributeValue) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlAttribute, AttributeValue), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlAttribute *node)
-{
-	node->attributeName = NULL;
-	node->attributeNameSpace = NULL;
-	node->AttributeValue = NULL;
-}
 
 static void
 class_init(LassoSamlAttributeClass *klass)
@@ -112,7 +113,8 @@ lasso_saml_attribute_get_type()
 			NULL,
 			sizeof(LassoSamlAttribute),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAML_ATTRIBUTE_DESIGNATOR,
@@ -123,9 +125,9 @@ lasso_saml_attribute_get_type()
 
 /**
  * lasso_saml_attribute_new:
- * 
+ *
  * Creates a new #LassoSamlAttribute object.
- * 
+ *
  * Return value: a newly created #LassoSamlAttribute object
  **/
 LassoSamlAttribute*
