@@ -1,10 +1,10 @@
-/* $Id: saml_attribute_value.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: Nicolas Clapies <nclapies@entrouvert.com>
  *          Valery Febvre <vfebvre@easter-eggs.com>
  *
@@ -12,12 +12,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -28,9 +28,9 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "xml.h"
 
 #define LASSO_TYPE_SAML_ATTRIBUTE_VALUE (lasso_saml_attribute_value_get_type())
 #define LASSO_SAML_ATTRIBUTE_VALUE(obj) \
@@ -45,7 +45,7 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAML_ATTRIBUTE_VALUE))
 #define LASSO_SAML_ATTRIBUTE_VALUE_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAML_ATTRIBUTE_VALUE, \
-				    LassoSamlAttributeValueClass)) 
+				    LassoSamlAttributeValueClass))
 
 typedef struct _LassoSamlAttributeValue LassoSamlAttributeValue;
 typedef struct _LassoSamlAttributeValueClass LassoSamlAttributeValueClass;
@@ -54,7 +54,7 @@ struct _LassoSamlAttributeValue {
 	LassoNode parent;
 
 	/*< public >*/
-	GList *any;
+	GList *any; /* of LassoNode */
 };
 
 struct _LassoSamlAttributeValueClass {
