@@ -1,28 +1,29 @@
-/* $Id: saml_authority_binding.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_authority_binding.h>
+#include "private.h"
+#include "saml_authority_binding.h"
 
 /**
  * SECTION:saml_authority_binding
@@ -30,7 +31,7 @@
  *
  * <figure><title>Schema fragment for saml:AuthorityBinding</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <element name="AuthorityBinding" type="saml:AuthorityBindingType"/>
  * <complexType name="AuthorityBindingType">
  *   <attribute name="AuthorityKind" type="QName" use="required"/>
@@ -47,25 +48,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AuthorityKind", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, AuthorityKind) },
+		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, AuthorityKind), NULL, NULL, NULL},
 	{ "Location", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, Location) },
+		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, Location), NULL, NULL, NULL},
 	{ "Binding", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, Binding) },
-	{ NULL, 0, 0 }
+		G_STRUCT_OFFSET(LassoSamlAuthorityBinding, Binding), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlAuthorityBinding *node)
-{
-	node->AuthorityKind = NULL;
-	node->Location = NULL;
-	node->Binding = NULL;
-}
 
 static void
 class_init(LassoSamlAuthorityBindingClass *klass)
@@ -93,7 +87,8 @@ lasso_saml_authority_binding_get_type()
 			NULL,
 			sizeof(LassoSamlAuthorityBinding),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -104,9 +99,9 @@ lasso_saml_authority_binding_get_type()
 
 /**
  * lasso_saml_authority_binding_new:
- * 
+ *
  * Creates a new #LassoSamlAuthorityBinding object.
- * 
+ *
  * Return value: a newly created #LassoSamlAuthorityBinding object
  **/
 LassoNode*
