@@ -1,28 +1,29 @@
-/* $Id: saml_statement_abstract.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_statement_abstract.h>
+#include "private.h"
+#include "saml_statement_abstract.h"
 
 /**
  * SECTION:saml_statement_abstract
@@ -45,11 +46,6 @@
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlStatementAbstract *node)
-{
-}
-
 static void
 class_init(LassoSamlStatementAbstractClass *klass)
 {
@@ -75,7 +71,8 @@ lasso_saml_statement_abstract_get_type()
 			NULL,
 			sizeof(LassoSamlStatementAbstract),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL,
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
