@@ -1,28 +1,29 @@
-/* $Id: saml_subject_confirmation.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_subject_confirmation.h>
+#include "private.h"
+#include "saml_subject_confirmation.h"
 
 /**
  * SECTION:saml_subject_confirmation
@@ -30,7 +31,7 @@
  *
  * <figure><title>Schema fragment for saml:SubjectConfirmation</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <element name="SubjectConfirmation" type="saml:SubjectConfirmationType"/>
  * <complexType name="SubjectConfirmationType">
  *   <sequence>
@@ -39,7 +40,7 @@
  *     <element ref="ds:KeyInfo" minOccurs="0"/>
  *   </sequence>
  * </complexType>
- * 
+ *
  * <element name="SubjectConfirmationData" type="anyType"/>
  * <element name="ConfirmationMethod" type="anyURI"/>
  * ]]></programlisting>
@@ -52,25 +53,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "ConfirmationMethod", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, ConfirmationMethod) },
+		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, ConfirmationMethod), NULL, NULL, NULL},
 	{ "SubjectConfirmationData", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, SubjectConfirmationData) },
+		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, SubjectConfirmationData), NULL, NULL, NULL},
 	{ "KeyInfo", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, KeyInfo) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlSubjectConfirmation, KeyInfo), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlSubjectConfirmation *node)
-{
-	node->ConfirmationMethod = NULL;
-	node->SubjectConfirmationData = NULL;
-	node->KeyInfo = NULL;
-}
 
 static void
 class_init(LassoSamlSubjectConfirmationClass *klass)
@@ -98,7 +92,8 @@ lasso_saml_subject_confirmation_get_type()
 			NULL,
 			sizeof(LassoSamlSubjectConfirmation),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -109,9 +104,9 @@ lasso_saml_subject_confirmation_get_type()
 
 /**
  * lasso_saml_subject_confirmation_new:
- * 
+ *
  * Creates a new #LassoSamlSubjectConfirmation object.
- * 
+ *
  * Return value: a newly created #LassoSamlSubjectConfirmation object
  **/
 LassoSamlSubjectConfirmation*
