@@ -1,22 +1,22 @@
-/* $Id: saml_subject_confirmation.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,10 +27,10 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
-#include <lasso/xml/ds_key_info.h>
+#include "xml.h"
+#include "ds_key_info.h"
 
 #define LASSO_TYPE_SAML_SUBJECT_CONFIRMATION (lasso_saml_subject_confirmation_get_type())
 #define LASSO_SAML_SUBJECT_CONFIRMATION(obj) \
@@ -45,7 +45,7 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION))
 #define LASSO_SAML_SUBJECT_CONFIRMATION_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_SAML_SUBJECT_CONFIRMATION, \
-				    LassoSamlSubjectConfirmationClass)) 
+				    LassoSamlSubjectConfirmationClass))
 
 typedef struct _LassoSamlSubjectConfirmation LassoSamlSubjectConfirmation;
 typedef struct _LassoSamlSubjectConfirmationClass LassoSamlSubjectConfirmationClass;
@@ -55,7 +55,7 @@ struct _LassoSamlSubjectConfirmation {
 
 	/*< public >*/
 	/* <element ref="saml:ConfirmationMethod" maxOccurs="unbounded"/> */
-	GList *ConfirmationMethod;
+	GList *ConfirmationMethod; /* of strings */
 	/* <element ref="saml:SubjectConfirmationData" minOccurs="0"/> */
 	char *SubjectConfirmationData;
 	LassoDsKeyInfo *KeyInfo;
