@@ -1,28 +1,29 @@
-/* $Id: samlp_status_code.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/samlp_status_code.h>
+#include "private.h"
+#include "samlp_status_code.h"
 
 /**
  * SECTION:samlp_status_code
@@ -30,7 +31,7 @@
  *
  * <figure><title>Schema fragment for samlp:StatusCode</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <element name="StatusCode" type="samlp:StatusCodeType"/>
  * <complexType name="StatusCodeType">
  *   <sequence>
@@ -47,21 +48,15 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "StatusCode", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSamlpStatusCode, StatusCode) },
-	{ "Value", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSamlpStatusCode, Value) },
-	{ NULL, 0, 0}
+	{ "StatusCode", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSamlpStatusCode, StatusCode), NULL, NULL, NULL},
+	{ "Value", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSamlpStatusCode, Value), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-
-static void
-instance_init(LassoSamlpStatusCode *node)
-{
-}
-
 static void
 class_init(LassoSamlpStatusCodeClass *klass)
 {
@@ -88,7 +83,8 @@ lasso_samlp_status_code_get_type()
 			NULL,
 			sizeof(LassoSamlpStatusCode),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
