@@ -1,28 +1,30 @@
-/* $Id: sec_resource_access_statement.c 3237 2007-05-30 17:17:45Z dlaniel $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/sec_resource_access_statement.h>
+#include "private.h"
+#include "sec_resource_access_statement.h"
+#include "./idwsf_strings.h"
 
 /*
  * <xs: element name="ResourceAccessStatement"
@@ -55,18 +57,13 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ NULL, 0, 0}
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSecResourceAccessStatement *node)
-{
-}
-
 static void
 class_init(LassoSecResourceAccessStatementClass *klass)
 {
@@ -74,7 +71,7 @@ class_init(LassoSecResourceAccessStatementClass *klass)
 
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "ResourceAccessStatement");
-	lasso_node_class_set_ns(nclass, LASSO_SAML_ASSERTION_HREF, LASSO_SAML_ASSERTION_PREFIX);
+	lasso_node_class_set_ns(nclass, LASSO_SEC_HREF, LASSO_SEC_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
 
@@ -93,7 +90,8 @@ lasso_sec_resource_access_statement_get_type()
 			NULL,
 			sizeof(LassoSecResourceAccessStatement),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAML_SUBJECT_STATEMENT_ABSTRACT,
@@ -104,7 +102,7 @@ lasso_sec_resource_access_statement_get_type()
 
 /**
  * lasso_sec_resource_access_statement_new:
- * 
+ *
  * Creates a new #LassoSecResourceAccessStatement object.
  *
  * Return value: a newly created #LassoSecResourceAccessStatement object
