@@ -1,28 +1,30 @@
-/* $Id: soap_binding_ext_credential.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/soap_binding_ext_credential.h>
+#include "private.h"
+#include "soap_binding_ext_credential.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:soap_binding_ext_credential
@@ -39,10 +41,10 @@
  *      <xs:attribute name="notOnOrAfter" type="xs:dateTime" use="optional"/>
  *   </xs:complexType>
  * </xs:element>
- * 
+ *
  * ]]></programlisting>
  * </figure>
- */ 
+ */
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -50,22 +52,16 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSoapBindingExtCredential, any) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredential, any), NULL, NULL, NULL},
 	{ "notOnOrAfter", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSoapBindingExtCredential, notOnOrAfter) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredential, notOnOrAfter), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSoapBindingExtCredential *node)
-{
-	node->any = NULL;
-	node->notOnOrAfter = NULL;
-}
 
 static void
 class_init(LassoSoapBindingExtCredentialClass *klass)
@@ -93,7 +89,8 @@ lasso_soap_binding_ext_credential_get_type()
 			NULL,
 			sizeof(LassoSoapBindingExtCredential),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -115,16 +112,3 @@ lasso_soap_binding_ext_credential_new(LassoNode *any)
 
 	return node;
 }
-
-LassoSoapBindingExtCredential*
-lasso_soap_binding_ext_credential_new_from_message(const gchar *message)
-{
-	LassoSoapBindingExtCredential *node;
-
-	g_return_val_if_fail(message != NULL, NULL);
-
-	node = g_object_new(LASSO_TYPE_SOAP_BINDING_EXT_CREDENTIAL, NULL);
-	lasso_node_init_from_message(LASSO_NODE(node), message);
-
-	return node;
-}
