@@ -1,28 +1,30 @@
-/* $Id: soap_binding_ext_credentials_context.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/soap_binding_ext_credentials_context.h>
+#include "private.h"
+#include "soap_binding_ext_credentials_context.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:soap_binding_ext_credentials_context
@@ -41,10 +43,10 @@
  *   <xs:attribute ref="S:actor" use="optional"/>
  * </xs:complexType>
  * <xs:element name="CredentialsContext" type="CredentialsContextType"/>
- * 
+ *
  * ]]></programlisting>
  * </figure>
- */ 
+ */
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -52,30 +54,21 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "RequestAuthnContext", SNIPPET_NODE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, RequestAuthnContext) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, RequestAuthnContext), NULL, NULL, NULL},
 	{ "SecurityMechID", SNIPPET_CONTENT,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, SecurityMechID) },
-	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, id) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, SecurityMechID), NULL, NULL, NULL},
+	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, id), NULL, NULL, NULL},
 	{ "mustUnderstand", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, mustUnderstand) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, mustUnderstand), NULL, NULL, NULL},
 	{ "actor", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, actor) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSoapBindingExtCredentialsContext, actor), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSoapBindingExtCredentialsContext *node)
-{
-	node->RequestAuthnContext = NULL;
-	node->SecurityMechID = NULL;
-	node->id = NULL;
-	node->mustUnderstand = NULL;
-	node->actor = NULL;
-}
 
 static void
 class_init(LassoSoapBindingExtCredentialsContextClass *klass)
@@ -103,7 +96,8 @@ lasso_soap_binding_ext_credentials_context_get_type()
 			NULL,
 			sizeof(LassoSoapBindingExtCredentialsContext),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -121,16 +115,3 @@ lasso_soap_binding_ext_credentials_context_new()
 
 	return node;
 }
-
-LassoSoapBindingExtCredentialsContext*
-lasso_soap_binding_ext_credentials_context_new_from_message(const gchar *message)
-{
-	LassoSoapBindingExtCredentialsContext *node;
-
-	g_return_val_if_fail(message != NULL, NULL);
-
-	node = g_object_new(LASSO_TYPE_SOAP_BINDING_EXT_CREDENTIALS_CONTEXT, NULL);
-	lasso_node_init_from_message(LASSO_NODE(node), message);
-
-	return node;
-}
