@@ -1,28 +1,30 @@
-/* $Id: soap_binding_ext_service_instance_update.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/soap_binding_ext_service_instance_update.h>
+#include "private.h"
+#include "soap_binding_ext_service_instance_update.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:soap_binding_ext_service_instance_update
@@ -48,10 +50,10 @@
  *   <xs:attribute ref="S:mustUnderstand" use="optional"/>
  *   <xs:attribute ref="S:actor" use="optional"/>
  * </xs:complexType>
- * 
+ *
  * ]]></programlisting>
  * </figure>
- */ 
+ */
 
 /*****************************************************************************/
 /* private methods                                                           */
@@ -59,33 +61,23 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "SecurityMechID", SNIPPET_CONTENT,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, SecurityMechID) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, SecurityMechID), NULL, NULL, NULL},
 	{ "Credential", SNIPPET_NODE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, Credential) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, Credential), NULL, NULL, NULL},
 	{ "Endpoint", SNIPPET_CONTENT,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, Endpoint) },
-	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, id) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, Endpoint), NULL, NULL, NULL},
+	{ "id", SNIPPET_ATTRIBUTE, G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, id), NULL, NULL, NULL},
 	{ "mustUnderstand", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, mustUnderstand) },
+		G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, mustUnderstand), NULL, NULL, NULL},
 	{ "actor", SNIPPET_ATTRIBUTE,
-	  G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, actor) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSoapBindingExtServiceInstanceUpdate, actor), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSoapBindingExtServiceInstanceUpdate *node)
-{
-	node->SecurityMechID = NULL;
-	node->Credential = NULL;
-	node->Endpoint = NULL;
-	node->id = NULL;
-	node->mustUnderstand = NULL;
-	node->actor = NULL;
-}
 
 static void
 class_init(LassoSoapBindingExtServiceInstanceUpdateClass *klass)
@@ -113,7 +105,8 @@ lasso_soap_binding_ext_service_instance_update_get_type()
 			NULL,
 			sizeof(LassoSoapBindingExtServiceInstanceUpdate),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -131,16 +124,3 @@ lasso_soap_binding_ext_service_instance_update_new()
 
 	return node;
 }
-
-LassoSoapBindingExtServiceInstanceUpdate*
-lasso_soap_binding_ext_service_instance_update_new_from_message(const gchar *message)
-{
-	LassoSoapBindingExtServiceInstanceUpdate *node;
-
-	g_return_val_if_fail(message != NULL, NULL);
-
-	node = g_object_new(LASSO_TYPE_SOAP_BINDING_EXT_SERVICE_INSTANCE_UPDATE, NULL);
-	lasso_node_init_from_message(LASSO_NODE(node), message);
-
-	return node;
-}
